%global momorel 48

Summary: The Linux kernel (the core of the Linux operating system)
Name: kernel

### include local configuration
%{?include_specopt}

### default configurations
#  If you'd like to change these configurations, please copy them to
# ${HOME}/rpm/specopt/kernel.specopt and edit it.
#
# and you should set in ~/.rpmmacros
# %_specoptdir %(echo $HOME)/rpm/specopt

###

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.
# All should default to 1 (enabled) and be flipped to 0 (disabled)
# by later arch-specific checks.

# The following build options are enabled by default.
# Use either --without <opt> in your rpmbuild command or force values
# to 0 in here to disable them.
#
#%%{?!buildup:              %global buildup   1}
%global buildup   1
# kernel-smp (only valid for ppc 32-bit, sparc64)
%{?!buildsmp:             %global buildsmp  0}
%{?!buildpae:             %global buildpae  1}
# Whether to apply the Xen patches, leave this enabled.
%{?!includexen:           %global includexen  0}
# Whether to build the Xen kernels, disable if you want.
%{?!buildxen:             %global buildxen  0}
%{?!builddoc:             %global builddoc  1}
%{?!buildkdump:           %global buildkdump  1}
%{?!buildheaders:         %global buildheaders  1}
%{?!builddebug:           %global builddebug  1}
#%%{?!debugbuildsenabled:   %global debugbuildsenabled  1}
%global debugbuildsenabled  1
%{?!_enable_debug_packages: %global _enable_debug_packages 0}

# Additional options for user-friendly one-off kernel building:
#
# Only build the base kernel (--with baseonly):
%global with_baseonly %{?_with_baseonly: 1} %{?!_with_baseonly: 0}
# Only build the smp kernel (--with smponly):
%global with_smponly  %{?_with_smponly:  1} %{?!_with_smponly:  0}
# Only build the base kernel (--with paeonly):
%global with_paeonly %{?_with_paeonly: 1} %{?!_with_paeonly: 0}
# Only build the xen kernel (--with xenonly):
%global with_xenonly  %{?_with_xenonly:  1} %{?!_with_xenonly:  0}

# Whether or not to gpg sign modules
%global  signmodules 0

# Do C=1 builds with sparse
%global usesparse 1 

# Whether or not to apply the Xen patches -- leave this enabled
#%%global includexen 0
# Xen doesn't work with current upstream kernel, shut it off
#%%global buildxen 0

# Set debugbuildsenabled to 1 for production (build separate debug kernels)
#  and 0 for rawhide (all kernels are debug kernels).
# See also 'make debug' and 'make release'.
#%%global debugbuildsenabled 1 

# Build with source extension patch
%global build_ext 1
%global patchlevel 16

# Build with kernel rc patch
%global build_rc 0 
%global rc_ver 9 

# Build with kernel snapshot patch
%global build_git 0 
%global git_ver 7 
# below is for 2.6.23-rc6-git5

# Build with kernel mm patch
%global build_mm 0

# Polite request for people who spin their own kernel rpms:
# please modify the "release" field in a way that identifies
# that the kernel isn't the stock distribution kernel, for example by
# adding some text to the end of the version number.
#
%global sublevel 23
%global kversion 2.6.%{sublevel}
%global rpmversion 2.6.%{sublevel}
%global srcversion 2.6.23 

%global release %{momorel}m

%if %{build_ext}
%global kversion_ext %{kversion}.%{patchlevel}
%endif

%if %{build_git}
%global kversion_git %{kversion}-git%{git_ver}
%endif

%if %{build_mm}
%global kversion_mm %{kversion}-mm%{mm_ver}
%endif

%if %{build_rc}
%global kversion_rc %{kversion}-rc%{rc_ver}
%global release 0.%{rc_ver}.%{momorel}m
%if %{build_git}
%global kversion_git %{kversion_rc}-git%{git_ver}
%global release 0.%{rc_ver}.git%{git_ver}.%{momorel}m
%endif
%if %{build_mm}
%global kversion_mm %{kversion_rc}-mm%{mm_ver}
%global release 0.%{rc_ver}.mm%{mm_ver}.%{momorel}m
%endif
%endif

## [TuxOnIce]
%global build_tuxonice 0

## [kdb] http://oss.sgi.com/projects/kdb/
%global build_kdb 0
%global kdb_ver v4.4
%global kdb_kernel_ver 2.6.22

## [unionfs]
%global build_unionfs 1 
%global unionfs_ver 2.2.3
%global unionfs_kernel_ver 2.6.23.14

## [madwifi]
%global build_madwifi 1
%global madwifi_snap_use 1 
%global madwifi_stable_ver 0.9.3.3
%global madwifi_snap_ver ng-r3344-20080207

## [ivtv]
%global build_ivtv 1
%global ivtv_ver 1.0.3

## [ipw3945 and 4965]
%global build_iwlwifi 0
%global iwlwifi_ver 1.2.23

## [nilfs]
%global nilfs_ver 2.0.0-testing-9
%global build_nilfs 1 

# [btrfs]
%global build_btrfs        1 
%global btrfs_ver          0.12

## [reiser4fs]
%global build_reiser4fs 1

## [xen]
%global xen_version 11633
%global xen_flags verbose=y crash_debug=y
%global xen_target vmlinuz
%global xen_image vmlinuz

%global make_target bzImage
%global kernel_image x86

%global KVERREL %{PACKAGE_VERSION}-%{PACKAGE_RELEASE}
%global hdrarch %_target_cpu

%if 0%{!?nopatches:1}
%global nopatches 0
%endif

%if %{nopatches}
%global includexen 0
%global variant -vanilla
%endif

%global using_upstream_branch 0

# groups of related archs
%global all_x86 i686

# if requested, only build base kernel
%if %{with_baseonly}
%global buildsmp 0
%global buildpae 0
%global buildxen 0
%global buildkdump 0
%global builddebug 0
%global debugbuildsenabled 0
%endif

# if requested, only build smp kernel
%if %{with_smponly}
%define with_up 0
%define with_pae 0
%define with_xen 0
%define with_kdump 0
%define with_debug 0
%endif

# if requested, only build pae kernel
%if %{with_paeonly}
%define with_up 0
%define with_smp 0
%define with_xen 0
%define with_kdump 0
%define with_debug 0
%endif

# if requested, only build xen kernel
%if %{with_xenonly}
%define with_up 0
%define with_smp 0
%define with_pae 0
%define with_kdump 0
%define with_debug 0
%endif

# Overrides for generic default options

# only ppc and sparc64 need separate smp kernels
%ifnarch ppc sparc64 alphaev56
%global buildsmp 0
%endif

# pae is only valid on i686
%ifnarch i686
%global buildpae 0
%endif

# xen only builds on i686, x86_64 and ia64
%ifnarch i686 x86_64 ia64
%global buildxen 0
%endif

# only build kernel-kdump on ppc64
# (no relocatable kernel support upstream yet)
%ifnarch ppc64
%global buildkdump 0
%endif

# don't do debug builds on anything but i686 and x86_64
%ifnarch i686 x86_64
%global builddebug 0 
%endif

# don't sign modules on these platforms
%ifarch s390 s390x sparc sparc64 ppc alpha
%global signmodules 0
%endif

# sparse blows up on ppc64
%ifarch ppc64 ppc alpha
%global usesparse 0
%endif

# Per-arch tweaks

%ifarch %{all_x86}
%global all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-i?86*.config
%global image_install_path boot
%global hdrarch i386
# we build always xen i686 HV with pae
%global xen_flags verbose=y crash_debug=y pae=y
%endif

%ifarch x86_64
%global all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-x86_64*.config
%global image_install_path boot
%endif

%ifarch ppc64
%global all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc64*.config
%global image_install_path boot
%global make_target vmlinux
%global kernel_image vmlinux
%global kernel_image_elf 1
%global hdrarch powerpc
%endif


%ifarch s390x
%global all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-s390x.config
%global image_install_path boot
%global make_target image
%global kernel_image arch/s390/boot/image
%global hdrarch s390
%endif

%ifarch sparc
%global all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-sparc.config
%global make_target image
%global kernel_image image
%endif

%ifarch sparc64
%global all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-sparc64*.config
%global make_target image
%global kernel_image image
%endif

%ifarch ppc
%global all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc*.config
%global image_install_path boot
%global make_target vmlinux
%global kernel_image vmlinux
%global kernel_image_elf 1
%global hdrarch powerpc
%endif

%ifarch ia64
%global all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ia64.config
%global image_install_path boot/efi/EFI/redhat
%global make_target compressed
%global kernel_image vmlinux.gz
# ia64 xen HV doesn't building with debug=y at the moment
%global xen_flags verbose=y crash_debug=y
%global xen_target compressed
%glocal xen_image vmlinux.gz
%endif

%ifarch alpha alphaev56
%global all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-alpha*.config
%global image_install_path boot
%global make_target vmlinux
%global kernel_image vmlinux
%endif

%if %{nopatches}
%global signmodules 0
%endif

# To temporarily exclude an architecture from being built, add it to
# %nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We don't build a kernel on i386; we only do kernel-headers there,
# and we no longer build for 31bit S390.
%global nobuildarches i386 s390

%ifarch %nobuildarches
%global buildup 0
%global buildsmp 0
%global buildpae 0
%global buildxen 0
%global buildkdump 0
%global _enable_debug_packages 0
%endif

#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.6 required versions as per
# Documentation/Changes
#
%global kernel_dot_org_conflicts  ppp < 2.4.3, isdn4k-utils < 3.2-32, nfs-utils < 1.0.7-12, e2fsprogs < 1.37-4, util-linux < 2.12, jfsutils < 1.1.7-2, reiserfs-utils < 3.6.19-2, xfsprogs < 2.6.13-4, procps < 3.2.5-6.3, oprofile < 0.9.1-2, reiser4fsprogs

#
# Then a series of requirements that are distribution specific, either
# because we add patches for something, or the older versions have
# problems with the newer kernel or lack certain things that make
# integration in the distro harder than needed.
#
%global package_conflicts initscripts < 7.23, udev < 063-6, iptables < 1.3.2-1, ipw2200-firmware < 2.4, selinux-policy-targeted < 1.25.3-14

#
# The ld.so.conf.d file we install uses syntax older ldconfig's don't grok.
#
%global xen_conflicts glibc < 2.3.5-1, xen < 3.0.1

#
# Packages that need to be installed before the kernel is, because the %post
# scripts use them.
#
%global kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, mkinitrd >= 6.0.9

Group: System Environment/Kernel
License: GPLv2
Version: %{rpmversion}
Release: %{release}%{?dist}
ExclusiveArch: noarch %{all_x86} x86_64 ppc ppc64 ia64
ExclusiveOS: Linux
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-drm-nouveau = 6
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReq: no
AutoProv: yes


#
# List the packages used during the kernel build
#
BuildPreReq: module-init-tools, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildPreReq: bzip2, findutils, gzip, m4, perl, make >= 3.78, diffutils

%if %{signmodules}
BuildPreReq: gnupg
%endif
BuildRequires: gcc >= 3.4.2, binutils >= 2.12, redhat-rpm-config
%if %{usesparse}
BuildRequires: sparse >= 0.3
%endif
BuildConflicts: rhbuildsys(DiskFree) < 2048Mb

Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-%{srcversion}.tar.bz2
NoSource: 0 

%if %{includexen}
Source2: xen-%{xen_version}.tar.bz2
%endif
#Source2: Config.mk
#%global sparsever 0.2
#Source3: sparse-%{sparsever}.tar.bz2

Source10: COPYING.modules
Source11: genkey
Source14: find-provides
Source15: merge.pl

Source21: kernel-%{kversion}-i686.config
Source22: kernel-%{kversion}-i686-debug.config
Source23: kernel-%{kversion}-i686-PAE.config
Source24: kernel-%{kversion}-i686-PAE-debug.config

Source25: kernel-%{kversion}-x86_64.config
Source26: kernel-%{kversion}-x86_64-debug.config

Source28: kernel-%{kversion}-ppc.config
Source29: kernel-%{kversion}-ppc-smp.config
Source30: kernel-%{kversion}-ppc64.config
Source31: kernel-%{kversion}-ppc64-kdump.config

#Source33: kernel-%{kversion}-s390.config
#Source35: kernel-%{kversion}-s390x.config

Source36: kernel-%{kversion}-ia64.config

# Source37: kernel-%{kversion}-i686-xen.config
Source38: kernel-%{kversion}-x86_64-xen.config
#Source39: kernel-%{kversion}-ia64-xen.config

#Source50: kernel-%{kversion}-sparc.config
#Source51: kernel-%{kversion}-sparc64.config
#Source52: kernel-%{kversion}-sparc64-smp.config

# Momonga logo
Source100: logo_momonga_mono.pbm
Source101: logo_momonga_vga16.ppm
Source102: logo_momonga_gray256.pgm
Source103: logo_momonga_clut224.ppm
Source104: logo_spu_clut224-momonga.ppm

# alsa-1.0.11
##%%global md5source2000 57534e4297cd683371402220e3753885
##%%NoSource 2000 ftp://ftp.alsa-project.org/pub/driver/%{ALSAsrcname} %{md5source2000}

##### driver for TC9020 32bit PCI 10/100/1000Mbps Ethernet MAC Controller
# http://www.tmi.com.tw/pp-TC9020.html
Source500: http://www.tmi.com.tw/Data/driver/TC902X_Linux.zip

## madwifi driver
%if %{build_madwifi}
%if %{madwifi_snap_use}
# Source2400: http://snapshots.madwifi.org/madwifi-ng-current.tar.gz
Source2400: http://snapshots.madwifi.org/madwifi-ng/madwifi-%{madwifi_snap_ver}.tar.gz
%else
Source2400: http://dl.sourceforge.net/sourceforge/madwifi/madwifi-%{madwifi_stable_ver}.tar.gz
%endif
NoSource: 2400
%endif

## iflwifi driver
%if %{build_iwlwifi}
# from http://intellinuxwireless.org/
Source2450: http://intellinuxwireless.org/iwlwifi/downloads/iwlwifi-%{iwlwifi_ver}.tgz
NoSource: 2450
%endif

## nilfs
%if %{build_nilfs}
Source2600: http://www.osrg.net/nilfs/download/nilfs-%{nilfs_ver}.tar.bz2
NoSource: 2600
%endif

## btrfs
%if %{build_btrfs}
Source2650: http://oss.oracle.com/projects/btrfs/dist/files/btrfs-%{btrfs_ver}.tar.bz2
NoSource: 2650
%endif

## ivtv
%if %{build_ivtv}
Source2700: http://dl.ivtvdriver.org/ivtv/archive/1.0.x/ivtv-%{ivtv_ver}.tar.gz
NoSource: 2700
%endif

#
# Patches 0 through 100 are meant for core subsystem upgrades
#
%if %{build_rc}
Patch0:  http://www.kernel.org/pub/linux/kernel/v2.6/testing/patch-%{kversion_rc}.bz2
NoPatch: 0
%endif

%if %{build_ext}
Patch1: http://www.kernel.org/pub/linux/kernel/v2.6/patch-%{kversion_ext}.bz2
NoPatch: 1
%endif

%if %{build_git}
%if %{build_rc}
Patch2: http://www.kernel.org/pub/linux/kernel/v2.6/snapshots/patch-%{kversion_rc}-git%{git_ver}.bz2
NoPatch: 2
%else
Patch2: http://www.kernel.org/pub/linux/kernel/v2.6/snapshots/patch-%{srcversion}-git%{git_ver}.bz2
NoPatch: 2
%endif
%endif

%if !%{nopatches}

Patch05: linux-2.6-upstream-reverts.patch

Patch7:  linux-phenom-revB2-TLB.patch

# Patches 10 through 99 are for things that are going upstream really soon.
Patch10: linux-2.6.23-utrace.patch
Patch15: linux-2.6-highres-timers.patch

Patch27: linux-2.6.23-sysfs_symlynk_failed.patch
Patch28: linux-2.6.23-device_rename.patch

Patch41: linux-2.6-sysrq-c.patch
Patch50: linux-2.6-ia64-build-id-linker-script-fix.patch
Patch60: linux-2.6-x86-tune-generic.patch
Patch70: linux-2.6-x86_64-silence-up-apic-errors.patch
Patch72: linux-2.6-x86-tsc-calibration-2.patch
Patch75: linux-2.6-x86-debug-boot.patch
Patch76: linux-2.6-x86-clean-up-oops-bug-reports.patch

Patch80: linux-2.6-alsa-1.0.15-merge-1.patch
Patch81: linux-2.6-alsa-1.0.15-merge-2.patch 
Patch82: linux-2.6-alsa-1.0.15-merge-3.patch
Patch86: linux-2.6-alsa-support-sis7019.patch
Patch87: linux-2.6-alsa-hda-stac-dmic.patch
Patch88: linux-2.6-alsa-drivers-set-device-links.patch
Patch89: linux-2.6-alsa-hda-fix-waitloop.patch
Patch90: linux-2.6-alsa-hda-stac-add-delay.patch

Patch100: linux-2.6-ppc-pegasos-via-ata-legacy-irq.patch
Patch101: linux-2.6-ppc-fix-dso-unwind.patch
Patch102: linux-2.6-rheap-modular.patch
Patch103: linux-2.6-bestcomm-dma.patch
Patch104: linux-2.6-fec_mpc52xx.patch
Patch110: linux-2.6-pasemi-smp-timebase-fix.patch
Patch111: linux-2.6-pasemi-broken-regread.patch
Patch112: linux-2.6-pasemi-getcfgaddr.patch
Patch113: linux-2.6-pasemi-5945-workaround.patch
Patch114: linux-2.6-pasemi-no-mpic-reset.patch
Patch115: linux-2.6-pasemi-mac.patch
Patch116: linux-2.6-pasemi-mdio-gpio.patch
Patch120: linux-2.6-ibmvscsi-schizo.patch
Patch121: linux-2.6-pmac-zilog.patch
Patch130: linux-2.6-powerpc-generic-suspend-2-remove-adb-sleep-notifier.patch
Patch131: linux-2.6-powerpc-generic-suspend-3-remove-dmasound.patch
Patch132: linux-2.6-powerpc-generic-suspend-4-kill-pmu-sleep-notifier.patch
Patch133: linux-2.6-powerpc-generic-suspend-5-pmu-pm_ops.patch
Patch140: linux-2.6-ps3-ehci-iso.patch
Patch141: linux-2.6-ps3-storage-alias.patch
Patch142: linux-2.6-ps3-legacy-bootloader-hack.patch
Patch143: linux-2.6-g5-therm-shutdown.patch
Patch144: linux-2.6-ppc32-ucmpdi2.patch

Patch150: linux-2.6-build-nonintconfig.patch
Patch160: linux-2.6-execshield.patch
Patch170: linux-2.6-modsign-mpilib.patch
Patch180: linux-2.6-modsign-crypto.patch
Patch190: linux-2.6-modsign-include.patch
Patch200: linux-2.6-modsign-verify.patch
Patch210: linux-2.6-modsign-ksign.patch
Patch220: linux-2.6-modsign-core.patch
Patch230: linux-2.6-modsign-script.patch
Patch240: linux-2.6-modules-modalias-platform.patch
Patch250: linux-2.6-debug-sizeof-structs.patch
Patch260: linux-2.6-debug-nmi-timeout.patch
Patch270: linux-2.6-debug-taint-vm.patch
Patch280: linux-2.6-debug-spinlock-taint.patch
Patch330: linux-2.6-debug-no-quiet.patch
Patch340: linux-2.6-debug-boot-delay.patch
Patch345: linux-2.6-debug-acpi-os-write-port.patch
Patch350: linux-2.6-devmem.patch
Patch370: linux-2.6-crash-driver.patch
Patch400: linux-2.6-scsi-cpqarray-set-master.patch
Patch401: linux-2.6-scsi-async-double-add.patch
Patch402: linux-2.6-scsi-mpt-vmware-fix.patch
Patch405: linux-2.6-scsi-initio-fix-hang-on-load.patch
Patch420: linux-2.6-squashfs-3.3.patch
Patch423: linux-2.6-gfs-locking-exports.patch
Patch424: linux-2.6-cifs-fix-incomplete-rcv.patch
Patch425: linux-2.6-cifs-typo-in-cifs_reconnect-fix.patch
Patch426: linux-2.6-cifs-fix-bad-handling-of-EAGAIN.patch

Patch430: linux-2.6-net-silence-noisy-printks.patch
Patch431: linux-2.6-netfilter-really-fix-oops-in-nf_nat_move_storage.patch
Patch440: linux-2.6-sha_alignment.patch
Patch450: linux-2.6-input-kill-stupid-messages.patch
Patch451: linux-2.6-input-fix-sync-loss-acer-aspire.patch
Patch452: linux-2.6-input-appletouch-macbook3-trackpad.patch
Patch460: linux-2.6-serial-460800.patch
Patch461: linux-2.6-serial_pnp-add-new-wacom-ids.patch
Patch480: linux-2.6-proc-self-maps-fix.patch
Patch510: linux-2.6-silence-noise.patch
Patch570: linux-2.6-selinux-mprotect-checks.patch
Patch571: linux-2.6-selinux-fix-netlabel-leak.patch
Patch572: linux-2.6-selinux-strip-leading-slashes.patch
Patch590: linux-2.6-unexport-symbols.patch
Patch600: linux-2.6-vm-silence-atomic-alloc-failures.patch
Patch602: linux-2.6-mm-fix-ptrace-access-beyond-vma.patch
Patch603: linux-2.6-dio-fix-cache-invalidation-after-sync-writes.patch
Patch604: linux-2.6-slub-provide-proc-slabinfo.patch
Patch605: linux-2.6-futex-fix-fixups.patch
Patch610: linux-2.6-defaults-fat-utf8.patch
Patch620: linux-2.6-defaults-unicode-vt.patch
Patch630: linux-2.6-defaults-nonmi.patch
Patch640: linux-2.6-defaults-nommconf.patch
Patch660: linux-2.6-libata-ali-atapi-dma.patch
Patch661: linux-2.6-libata-acpi-enable.patch
Patch662: linux-2.6-libata-add-dma-disable-option.patch
Patch665: linux-2.6-libata-dont-fail-revalidation-for-bad-gtf-methods.patch
Patch666: linux-2.6-libata-pata_serverworks-fix-drive-combinations.patch
Patch667: linux-2.6-libata-correct-iordy-handling.patch
Patch670: linux-2.6-ata-quirk.patch
Patch671: linux-2.6-libata-tape-max-sectors.patch
Patch672: linux-2.6-libata-work-around-drq-1-err-1-for-tapes.patch
Patch673: linux-2.6-libata-use-stuck-err-for-tapes.patch
Patch674: linux-2.6-libata-scsi-allow-short-commands.patch
Patch675: linux-2.6-libata-ahci-enable-ahci-mode-before-reset.patch
Patch676: linux-2.6-libata-fix-bogus-lba48-disks.patch

Patch680: linux-2.6-wireless.patch
Patch681: linux-2.6-wireless-pending.patch
Patch690: linux-2.6-at76.patch
Patch691: linux-2.6-rndis_wext.patch
Patch692: linux-2.6-ath5k-use-soft-wep.patch
Patch694: linux-2.6.23-GWUS54GXS.patch
Patch700: linux-2.6-cfg80211-extras.patch
Patch701: linux-2.6-zd1211rw-module-alias.patch
Patch710: linux-2.6-netdev-e1000e-01.patch
Patch711: linux-2.6-netdev-e1000e-02.patch
Patch712: linux-2.6-netdev-e1000e-03.patch
Patch713: linux-2.6-netdev-e1000e-04.patch
Patch714: linux-2.6-netdev-e1000e-05.patch
Patch715: linux-2.6-netdev-e1000e-06.patch
Patch716: linux-2.6-netdev-e1000e-07.patch
Patch717: linux-2.6-netdev-e1000e-08.patch
Patch718: linux-2.6-netdev-e1000e-09.patch
Patch719: linux-2.6-netdev-e1000e-10.patch
Patch720: linux-2.6-e1000-bad-csum-allow.patch
Patch721: linux-2.6-netdev-e1000-disable-alpm.patch
Patch725: linux-2.6-netdev-atl2-2.0.3.patch
Patch730: linux-2.6-netdev-spidernet-fix-interrupt-handling.patch
Patch731: linux-2.6-netdev-smc91c92_cs-fix-station-addr.patch
#Patch780: linux-2.6-clockevents-fix-resume-logic.patch
Patch750: linux-2.6-acpi-git-ec-init-fixes.patch
Patch761: linux-2.6-acpi-video-backlight-rationalize.patch
Patch762: linux-2.6-acpi-video-brightness-bigger-buffer.patch
Patch763: linux-2.6-acpi-video-fix-multiple-busses.patch
Patch770: linux-2.6-pmtrace-time-fix.patch
Patch775: linux-2.6-acpi-button-send-initial-state.patch
Patch780: linux-2.6-acpi-cpuidle-0-upstream.patch
Patch781: linux-2.6-acpi-cpuidle-1-fix-C3-for-no-bm-ctrl.patch
Patch782: linux-2.6-acpi-cpuidle-2-fix-HP-nx6125-regression.patch
Patch783: linux-2.6-acpi-dont-init-ec-early-with-no-ini.patch
Patch784: linux-2.6-acpi-eeepc-hotkey.patch
Patch785: linux-2.6-acpi_ec_early_init_fix.patch
Patch800: linux-2.6-wakeups-hdaps.patch
Patch801: linux-2.6-wakeups.patch
Patch820: linux-2.6-compile-fixes.patch

Patch999: sched-cfs-v2.6.23.12-v24.1.patch

Patch1100: linux-2.6-add-mmf_dump_elf_headers.patch
Patch1101: linux-2.6-default-mmf_dump_elf_headers.patch
Patch1102: linux-2.6-add-sys-module-name-notes.patch
Patch1103: linux-2.6-i386-vdso-install-unstripped-copies-on-disk.patch
Patch1105: linux-2.6-powerpc-vdso-install-unstripped-copies-on-disk.patch
Patch1106: linux-2.6-x86_64-ia32-vdso-install-unstripped-copies-on-disk.patch
Patch1107: linux-2.6-x86_64-vdso-install-unstripped-copies-on-disk.patch
Patch1108: linux-2.6-pass-g-to-assembler-under-config_debug_info.patch
Patch1109: linux-2.6-powerpc-lparmap-g.patch

Patch1300: linux-2.6-usb-suspend-classes.patch
Patch1305: linux-2.6-usb-storage-initialize-huawei-e220-properly.patch
Patch1306: linux-2.6-usb-storage-always-set-the-allow_restart-flag.patch
Patch1307: linux-2.6-usb-huawei-fix-init-in-modem-mode.patch
Patch1400: linux-2.6-smarter-relatime.patch
Patch1503: linux-2.6-xfs-optimize-away-dmapi-tests.patch
Patch1504: linux-2.6-xfs-optimize-away-realtime-tests.patch
Patch1505: linux-2.6-xfs-refactor-xfs_mountfs.patch
Patch1509: linux-2.6-xfs-setfattr-32bit-compat.patch
Patch1515: linux-2.6-lirc.patch
Patch1520: linux-2.6-dcdbas-autoload.patch

Patch1610: linux-2.6-pci-dont-size-transparent-bridges.patch

# Momonga logo
Patch12: linux-2.6-logo_momonga.patch

#TuxOnIce
# URL: http://www.tuxonice.net/downloads/all/
#      (ex:  tuxonice-2.2.10.4-for-2.6.23-rc9.tar.bz2)
#                  (tuxonicever) (tuxonicekver)
%global tuxonicever 3.0-rc5 
%global tuxonicekver 2.6.23.14
%global tuxonicename tuxonice-%{tuxonicever}-for-%{tuxonicekver}
%if %{build_tuxonice}
Patch35: http://www.tuxonice.net/downloads/all/%{tuxonicename}.patch.bz2
NoPatch: 35
%endif

# kdb
%if %{build_kdb}
Patch60: ftp://oss.sgi.com/www/projects/kdb/download/%{kdb_ver}/kdb-%{kdb_ver}-%{kdb_kernel_ver}-common-2.bz2
Patch61: ftp://oss.sgi.com/www/projects/kdb/download/%{kdb_ver}/kdb-%{kdb_ver}-%{kdb_kernel_ver}-i386-1.bz2
Patch62: ftp://oss.sgi.com/www/projects/kdb/download/%{kdb_ver}/kdb-%{kdb_ver}-%{kdb_kernel_ver}-ia64-1.bz2
Patch63: ftp://oss.sgi.com/www/projects/kdb/download/%{kdb_ver}/kdb-%{kdb_ver}-%{kdb_kernel_ver}-x86_64-1.bz2
%endif

Patch10110: linux-2.6-debug-slab-backtrace.patch
Patch1310: madwifi-Makefile.inc-r2323-20070512.patch

# Reiser4
%if %{build_reiser4fs}
%global md5patch1410 15fa3bd0be5100fd5941093e471acd66
#%%NoPatch 1410 http://ftp.namesys.com/pub/reiser4-for-2.6/2.6.22/reiser4-for-2.6.22.patch.gz %{md5patch1410}
Patch1410: http://chichkin_i.zelnet.ru/namesys/reiser4-for-2.6.23-3.patch.gz

%endif

# ReiserFS
Patch1440: reiserfs-workaround-for-dead-loop-in-finish_unfinished.patch
Patch1441: reiserfs-workaround-for-dead-loop-in-finish_unfinished-fix.patch

# nilfs
#%if %{build_nilfs}
#Patch1450: nilfs-1.0.10-Makefile.patch
#%endif

# btrfs
%if %{build_btrfs}
%endif

# unionfs
%if %{build_unionfs}
Patch1460: ftp://ftp.fsl.cs.sunysb.edu/pub/unionfs/unionfs-2.1/unionfs-%{unionfs_ver}_for_%{unionfs_kernel_ver}.diff.gz
%endif

Patch1480: mm-clean-up-and-kernelify-shrinker-registration.patch
Patch1485: shrink_slab-handle-bad-shrinkers.patch

#nouveau + drm fixes
Patch1800: drm-mm-git.patch
Patch1801: nouveau-drm.patch
Patch1802: linux-2.6-drm-radeon-update.patch
Patch1803: linux-2.6-git-initial-r500-drm.patch

# Updated firewire stack from linux1394 git
# snap from http://me.in-berlin.de/~s5r6/linux1394/updates/2.6.23/
Patch1910: linux-2.6-firewire-git-update.patch
# Work around E100 NAPI bug
Patch2000: linux-2.6-net-e100-disable-polling.patch
# fix thinkpad key events for volume/brightness
Patch2100: linux-2.6-thinkpad-key-events.patch
# SELinux performance patches
Patch2200: linux-2.6-selinux-no-revalidate-read-write.patch
Patch2201: linux-2.6-selinux-ebitmap-for-avc-miss.patch
Patch2202: linux-2.6-selinux-ebitmap-for-avc-miss-cleanup.patch
Patch2203: linux-2.6-selinux-sigchld-wait.patch
Patch2204: linux-2.6-selinux-ebitmap-loop-bug.patch

# Patch2300: linux-2.6-freezer-fix-apm-emulation-breakage.patch

# Patch2500: For compilation of NVIDIA driver (ver 1.0-6111)
##   http://www.uwsg.indiana.edu/hypermail/linux/kernel/0410.2/0753.html
Patch2500: http://ck.kolivas.org/patches/2.6/2.6.9/2.6.9-ck1/patches/nvidia_compat.diff
NoPatch: 2500 

# alsa-drivers for ONKYO SE-200PCI and SE-90PCI
Patch2600: alsa-driver-1.0.15rc3-SE200PCI.patch

# Suport MacBook JIS Keyboard
Patch2700: kernel-2.6.23-macbook-jis-keyboard.patch

# Misc bits.

Patch3000: thinkpad-acpi-0.19-20080213_v2.6.23.16.patch.gz

# gcc-4.3
Patch3100: linux-2.6-compile-fix-gcc-43.patch

%endif
# END OF PATCH DEFINITIONS

BuildRoot: %{_tmppath}/%{name}-%{version}-root

# Override find_provides to use a script that provides "kernel(symbol) = hash".
# Pass path of the RPM temp dir containing kabideps to find-provides script.
#global _use_internal_dependency_generator 0
#define __find_provides %_sourcedir/find-provides %{_tmppath}
#define __find_requires /usr/lib/rpm/redhat/find-requires kernel

%ifarch x86_64
Obsoletes: kernel-smp
%endif

%description
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

%package debuginfo
Summary: Debug information for package %{name}
Group: Development/Debuggers
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
Provides: %{name}-debuginfo-%{_target_cpu} = %{KVERREL}
%description debuginfo
This package provides debug information for package %{name}
This is required to use SystemTap with %{name}-%{KVERREL}.

%package debuginfo-common
Summary: Kernel source files used by %{name}-debuginfo packages
Group: Development/Debuggers
Provides: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
%description debuginfo-common
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.

%package devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
AutoReqProv: no
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}
Prereq: findutils

%description devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.

%package smp
Summary: The Linux kernel compiled for SMP machines.
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-drm-nouveau = 6
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}smp
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
# upto and including kernel 2.4.9 rpms, the 4Gb+ kernel was called kernel-enterprise
# now that the smp kernel offers this capability, obsolete the old kernel
Obsoletes: kernel-enterprise < 2.4.10
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReq: no
AutoProv: yes
%description smp
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs as well as machines with
hyperthreading technology.

Install the kernel-smp package if your machine uses two or more CPUs.

%package smp-debuginfo
Summary: Debug information for package %{name}-smp
Group: Development/Debuggers
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
Provides: %{name}-%smp-debuginfo-%{_target_cpu} = %{KVERREL}
%description smp-debuginfo
This package provides debug information for package %{name}-smp
This is required to use SystemTap with %{name}-smp-%{KVERREL}.

%package smp-devel
Summary: Development package for building kernel modules to match the SMP kernel.
Group: System Environment/Kernel
Provides: kernel-smp-devel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}smp
Provides: kernel-devel = %{rpmversion}-%{release}smp
AutoReqProv: no
Prereq: findutils

%description smp-devel
This package provides kernel headers and makefiles sufficient to build modules
against the SMP kernel package.

%package PAE
Summary: The Linux kernel compiled for PAE capable machines.
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-drm-nouveau = 6
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}PAE
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Obsoletes: kernel-smp < 2.6.17
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReq: no
AutoProv: yes
%description PAE
This package includes a version of the Linux kernel with support for up to
64GB of high memory. It requires a CPU with Physical Address Extensions (PAE).
The non-PAE kernel can only address up to 4GB of memory.
Install the kernel-PAE package if your machine has more than 4GB of memory.

%package PAE-debuginfo
Summary: Debug information for package %{name}-PAE
Group: Development/Debuggers
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
Provides: %{name}-%PAE-debuginfo-%{_target_cpu} = %{KVERREL}
%description PAE-debuginfo
This package provides debug information for package %{name}-PAE
This is required to use SystemTap with %{name}-PAE-%{KVERREL}.

%package PAE-devel
Summary: Development package for building kernel modules to match the PAE kernel.
Group: System Environment/Kernel
Provides: kernel-PAE-devel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}PAE
Provides: kernel-devel = %{rpmversion}-%{release}PAE
AutoReqProv: no
Prereq: findutils
%description PAE-devel
This package provides kernel headers and makefiles sufficient to build modules
against the PAE kernel package.

%if %{debugbuildsenabled}
%if %{builddebug}
%package PAE-debug
Summary: The Linux kernel compiled with extra debugging enabled for PAE capable machines.
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-drm-nouveau = 6
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}PAE-debug
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
AutoReq: no
AutoProv: yes
%description PAE-debug
This package includes a version of the Linux kernel with support for up to
64GB of high memory. It requires a CPU with Physical Address Extensions (PAE).
The non-PAE kernel can only address up to 4GB of memory.
Install the kernel-PAE package if your machine has more than 4GB of memory.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.

%package PAE-debug-debuginfo
Summary: Debug information for package %{name}-PAE-debug
Group: Development/Debuggers
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
Provides: %{name}-debug-debuginfo-%{_target_cpu} = %{KVERREL}
%description PAE-debug-debuginfo
This package provides debug information for package %{name}-PAE-debug

%package PAE-debug-devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
AutoReqProv: no
Prereq: findutils
Provides: kernel-PAE-debug-devel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}PAE-debug
Provides: kernel-devel = %{rpmversion}-%{release}PAE-debug
%description PAE-debug-devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.
%endif
%endif


%package doc
Summary: Various documentation bits found in the kernel source.
Group: Documentation
%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package headers
Summary: Header files for the Linux kernel for use by glibc
Group: Development/System
Obsoletes: glibc-kernheaders
Provides: glibc-kernheaders = 3.0-46
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.


%if %{debugbuildsenabled}
%if %{builddebug}
%package debug
Summary: The Linux kernel compiled with extra debugging enabled.
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-drm-nouveau = 6
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}debug
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
AutoReq: no
AutoProv: yes
%description debug
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.

%package debug-debuginfo
Summary: Debug information for package %{name}-debug
Group: Development/Debuggers
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
Provides: %{name}-debug-debuginfo-%{_target_cpu} = %{KVERREL}
%description debug-debuginfo
This package provides debug information for package %{name}-debug

%package debug-devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
AutoReqProv: no
Prereq: findutils
Provides: kernel-debug-devel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}debug
Provides: kernel-devel = %{rpmversion}-%{release}debug
%description debug-devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.
%endif
%endif


%package xen
Summary: The Linux kernel compiled for Xen VM operations
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}xen
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{xen_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReq: no
AutoProv: yes
%description xen
This package includes a version of the Linux kernel which
runs in Xen VM. It works for both priviledged and unpriviledged guests.

%package xen-debuginfo
Summary: Debug information for package %{name}-xen
Group: Development/Debuggers
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
Provides: %{name}-xen-debuginfo-%{_target_cpu} = %{KVERREL}
%description xen-debuginfo
This package provides debug information for package %{name}-xen
This is required to use SystemTap with %{name}-xen-%{KVERREL}.

%package xen-devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
AutoReqProv: no
Provides: kernel-xen-devel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}xen
Provides: kernel-devel = %{rpmversion}-%{release}xen
Prereq: findutils

%description xen-devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.

%package kdump
Summary: A minimal Linux kernel compiled for kernel crash dumps.

Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-drm-nouveau = 6
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}kdump
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReq: no
AutoProv: yes
%description kdump
This package includes a kdump version of the Linux kernel. It is
required only on machines which will use the kexec-based kernel crash dump
mechanism.

%package kdump-debuginfo
Summary: Debug information for package %{name}-kdump
Group: Development/Debuggers
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
Provides: %{name}-kdump-debuginfo-%{_target_cpu} = %{KVERREL}
%description kdump-debuginfo
This package provides debug information for package %{name}-kdump
This is required to use SystemTap with %{name}-kdump-%{KVERREL}.

%package kdump-devel
Summary: Development package for building kernel modules to match the kdump kernel.
Group: System Environment/Kernel
Provides: kernel-kdump-devel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}kdump
Provides: kernel-devel = %{rpmversion}-%{release}kdump
AutoReqProv: no
Prereq: findutils

%description kdump-devel
This package provides kernel headers and makefiles sufficient to build modules
against the kdump kernel package.

%prep
print_specopt() {
## echo the specopt values
cat <<EOF
Configurations:
  header arch ........... %{hdrarch}
    
Generic kernel packages:
  buildup ............... %{buildup}
  buildsmp .............. %{buildsmp}
  buildpae .............. %{buildpae}
  includexen ............ %{includexen}
  buildxen .............. %{buildxen}
  builddoc .............. %{builddoc}
  buildkdump ............ %{buildkdump}
  buildheaders .......... %{buildheaders}
  builddebug ............ %{builddebug}
  debugbuildsenabled..... %{debugbuildsenabled}
  _enable_debug_packages .. %{_enable_debug_packages}

Extras:
  TuxOnIce .............. %{build_tuxonice}
  kdb ................... %{build_kdb}
  madwifi ............... %{build_madwifi}
  iwlwifi ............... %{build_iwlwifi}
  nilfs ................. %{build_nilfs}
  btrfs ................. %{build_btrfs}
  unionfs ............... %{build_unionfs} 
EOF
}

print_specopt | tee kernel-specopt.log

# First we unpack the kernel tarball.
# If this isn't the first make prep, we use links to the existing clean tarball
# which speeds things up quite a bit.
if [ ! -d kernel-%{kversion}/vanilla ]; then
  # Ok, first time we do a make prep.
  rm -f pax_global_header
%setup -q -n kernel-%{version} -c
  mv linux-%{srcversion} vanilla
else
  # We already have a vanilla dir.
  cd kernel-%{kversion}
  if [ -d linux-%{kversion}.%{_target_cpu} ]; then
     # Just in case we ctrl-c'd a prep already
     rm -rf deleteme.%{_target_cpu}
     # Move away the stale away, and delete in background.
     mv linux-%{kversion}.%{_target_cpu} deleteme.%{_target_cpu}
     rm -rf deleteme.%{_target_cpu} &
  fi
fi

cp -rl vanilla linux-%{kversion}.%{_target_cpu}

pushd linux-%{kversion}.%{_target_cpu}
# Momonga logo
cp %{SOURCE100} drivers/video/logo
cp %{SOURCE101} drivers/video/logo
cp %{SOURCE102} drivers/video/logo
cp %{SOURCE103} drivers/video/logo
cp %{SOURCE104} drivers/video/logo/logo_spu_clut224.ppm
popd

# expand other sources
# tar zxf %{SOURCE2000}

%if %{build_madwifi}
tar zxf %{SOURCE2400}
%endif

%if %{build_iwlwifi}
tar zxf %{SOURCE2450}
%endif

%if %{build_nilfs}
tar jxf %{SOURCE2600}
%endif

%if %{build_btrfs}
tar jxf %{SOURCE2650}
%endif

# ivtv
%if %{build_ivtv}
tar zxf %{SOURCE2700}
%endif

cd linux-%{kversion}.%{_target_cpu}

patch_command='patch -p1 -F1 -s'
ApplyPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1;
  fi
  case "$patch" in
  *.bz2) bunzip2 < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.gz) gunzip < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *) $patch_command ${1+"$@"} < "$RPM_SOURCE_DIR/$patch" ;;
  esac
}

%if %{build_rc}
# Apply latest prepatch
ApplyPatch patch-%{kversion_rc}.bz2
%endif

%if %{build_ext}
# Update to latest upstream.
ApplyPatch patch-%{kversion_ext}.bz2
%endif

%if %{build_git}
# Apply snapshot git patch
%if %{build_rc}
ApplyPatch patch-%{kversion_rc}-git%{git_ver}.bz2
%else
ApplyPatch patch-%{kversion_git}.bz2
%endif
%endif

%if !%{nopatches}

# Momonga logo patch
#ApplyPatch linux-2.6-logo_momonga.patch
%patch12 -p1

# Revert -stable pieces we get from elsewhere here
ApplyPatch linux-2.6-upstream-reverts.patch -R

# Ingo's new scheduler.
ApplyPatch sched-cfs-v2.6.23.12-v24.1.patch

# Assorted dyntick/clock/timer fixes.
#ApplyPatch linux-2.6-clockevents-fix-resume-logic.patch
ApplyPatch linux-2.6-highres-timers.patch

# Roland's utrace ptrace replacement.
ApplyPatch $(basename %{P:10}) -F2

# setuid /proc/self/maps fix. (dependent on utrace)
ApplyPatch linux-2.6-proc-self-maps-fix.patch

# ALSA 1.0.15
ApplyPatch linux-2.6-alsa-1.0.15-merge-1.patch
ApplyPatch linux-2.6-alsa-1.0.15-merge-2.patch
ApplyPatch linux-2.6-alsa-1.0.15-merge-3.patch
# support SiS 7019 audio (for K12LTSP thin client)
ApplyPatch linux-2.6-alsa-support-sis7019.patch
# ALSA enhancments for 2.6.25
ApplyPatch linux-2.6-alsa-hda-stac-dmic.patch
# Fix missing controls on some devices caused by missing sysfs links
ApplyPatch linux-2.6-alsa-drivers-set-device-links.patch
# Fix wait loop so devices don't go into polling mode
ApplyPatch linux-2.6-alsa-hda-fix-waitloop.patch
# some STAC codecs need longer delay
ApplyPatch linux-2.6-alsa-hda-stac-add-delay.patch

# Nouveau DRM + drm fixes
ApplyPatch drm-mm-git.patch
ApplyPatch nouveau-drm.patch
ApplyPatch linux-2.6-drm-radeon-update.patch
ApplyPatch linux-2.6-git-initial-r500-drm.patch

# enable sysrq-c on all kernels, not only kexec
ApplyPatch linux-2.6-sysrq-c.patch

ApplyPatch linux-2.6.23-sysfs_symlynk_failed.patch
ApplyPatch linux-2.6.23-device_rename.patch

# Architecture patches
# IA64
ApplyPatch linux-2.6-ia64-build-id-linker-script-fix.patch

# AMD Phenom Processor Revision-B2 TLB bug fix
ApplyPatch linux-phenom-revB2-TLB.patch -z .phenom

%if %{build_tuxonice}
%ifarch %{ix86} x86_64
# TuxOnIce
ApplyPatch tuxonice-3.0-rc5-for-2.6.23.14.patch.bz2
%endif
%endif

# TC9020
mkdir TC902X
pushd TC902X
%{__unzip} %{SOURCE500}
%{__cp} README.TXT ../Documentation/networking/tc902x.txt
%{__tar} zxf tc902x.v203.tar.gz
mkdir ../drivers/net/tc902x
%{__cp} *.h *.c ../drivers/net/tc902x/
%{__mv} ../drivers/net/tc902x/tc902x.c ../drivers/net/tc902x/tc902x_core.c
chmod 644 ../drivers/net/tc902x/*
popd

# kdb
%if %{build_kdb}
ApplyPatch kdb-v4.4-2.6.22-rc4-common-2.bz2  
ApplyPatch kdb-v4.4-2.6.22-rc4-i386-1.bz2
ApplyPatch kdb-v4.4-2.6.22-rc4-ia64-1.bz2
ApplyPatch kdb-v4.4-2.6.22-rc4-x86_64-1.bz2
%endif

#
# x86(-64)
#
# Compile 686 kernels tuned for Pentium4.
ApplyPatch linux-2.6-x86-tune-generic.patch
# Suppress APIC errors on UP x86-64.
#ApplyPatch linux-2.6-x86_64-silence-up-apic-errors.patch# debug early boot
# fix x86 tsc clock calibration
ApplyPatch linux-2.6-x86-tsc-calibration-2.patch
# debug early boot
#ApplyPatch linux-2.6-x86-debug-boot.patch
# shorter i386 oops reports (scheduled for 2.6.24)
ApplyPatch linux-2.6-x86-clean-up-oops-bug-reports.patch

#
# PowerPC
#
###  UPSTREAM PATCHES FROM 2.6.24:
# pegasos IDE fixups
ApplyPatch linux-2.6-ppc-pegasos-via-ata-legacy-irq.patch
# fix unwind
ApplyPatch linux-2.6-ppc-fix-dso-unwind.patch
# FEC support on MPC52xx
ApplyPatch linux-2.6-rheap-modular.patch
ApplyPatch linux-2.6-bestcomm-dma.patch
ApplyPatch linux-2.6-fec_mpc52xx.patch
# Fixups for PA Semi Electra
ApplyPatch linux-2.6-pasemi-smp-timebase-fix.patch
ApplyPatch linux-2.6-pasemi-broken-regread.patch
ApplyPatch linux-2.6-pasemi-getcfgaddr.patch
ApplyPatch linux-2.6-pasemi-5945-workaround.patch
ApplyPatch linux-2.6-pasemi-no-mpic-reset.patch
ApplyPatch linux-2.6-pasemi-mac.patch
ApplyPatch linux-2.6-pasemi-mdio-gpio.patch
# Fix up ibmvscsi for combined pSeries/iSeries build
ApplyPatch linux-2.6-ibmvscsi-schizo.patch
# Move pmac_zilog to its newly-registered device number
ApplyPatch linux-2.6-pmac-zilog.patch
###  UPSTREAM PATCHES FROM 2.6.25 (we think):
# Suspend through /sys/power/state for PowerMac instead of magic ioctl
ApplyPatch linux-2.6-powerpc-generic-suspend-2-remove-adb-sleep-notifier.patch
ApplyPatch linux-2.6-powerpc-generic-suspend-3-remove-dmasound.patch
ApplyPatch linux-2.6-powerpc-generic-suspend-4-kill-pmu-sleep-notifier.patch
ApplyPatch linux-2.6-powerpc-generic-suspend-5-pmu-pm_ops.patch
###  NOT (YET) UPSTREAM:
# The EHCI ISO patch isn't yet upstream but is needed to fix reboot
ApplyPatch linux-2.6-ps3-ehci-iso.patch
# The storage alias patch is Fedora-local, and allows the old 'ps3_storage'
# module name to work on upgrades. Otherwise, I believe mkinitrd will fail
# to pull the module in,
ApplyPatch linux-2.6-ps3-storage-alias.patch
# Support booting from Sony's original released 2.6.16-based kboot
ApplyPatch linux-2.6-ps3-legacy-bootloader-hack.patch
# Alleviate G5 thermal shutdown problems
ApplyPatch linux-2.6-g5-therm-shutdown.patch
# Temporary hack to work around GCC PR #25724 / #21237
ApplyPatch linux-2.6-ppc32-ucmpdi2.patch


#
# Bugfixes to the core system and patches related to how RPMs are build
#
%endif

# This patch adds a "make nonint_oldconfig" which is non-interactive and
# also gives a list of missing options at the end. Useful for automated
# builds (as used in the buildsystem).
ApplyPatch $(basename %{P:150})

%if !%{nopatches}
# Exec shield 
ApplyPatch linux-2.6-execshield.patch

#
# GPG signed kernel modules
#

#
# Xen
#
%if %{includexen}
ApplyPatch linux-2.6-xen.patch
%endif

#
# bugfixes to drivers and filesystems
#

# pc speaker autoload
ApplyPatch linux-2.6-modules-modalias-platform.patch

# Various low-impact patches to aid debugging.
ApplyPatch linux-2.6-debug-sizeof-structs.patch
ApplyPatch linux-2.6-debug-nmi-timeout.patch
ApplyPatch linux-2.6-debug-taint-vm.patch
ApplyPatch linux-2.6-debug-spinlock-taint.patch

%if ! %{debugbuildsenabled}
ApplyPatch linux-2.6-debug-no-quiet.patch
# Only spew extra warnings on rawhide builds.
ApplyPatch linux-2.6-debug-extra-warnings.patch
# Turn slub debug on by default in rawhide
ApplyPatch linux-2.6-debug-slub-debug.patch
%endif

ApplyPatch linux-2.6-debug-boot-delay.patch
# try to find out what is breaking acpi-cpufreq
ApplyPatch linux-2.6-debug-acpi-os-write-port.patch

#
# Make /dev/mem a need-to-know function
#
ApplyPatch linux-2.6-devmem.patch

#
# /dev/crash driver for the crashdump analysis tool
#
ApplyPatch linux-2.6-crash-driver.patch

# driver core
#
# don't resize transparent bridges
ApplyPatch linux-2.6-pci-dont-size-transparent-bridges.patch

#
# SCSI Bits.
#
# fix cpqarray pci enable
ApplyPatch linux-2.6-scsi-cpqarray-set-master.patch
# Fix async scanning double-add problems
ApplyPatch linux-2.6-scsi-async-double-add.patch
# fix vmware emulated scsi controller
ApplyPatch linux-2.6-scsi-mpt-vmware-fix.patch
# fin initio driver
ApplyPatch linux-2.6-scsi-initio-fix-hang-on-load.patch

# Filesystem patches.
# Squashfs
ApplyPatch linux-2.6-squashfs-3.3.patch
# export symbols for gfs2 locking modules
ApplyPatch linux-2.6-gfs-locking-exports.patch
# cifs kernel memory corruption fixes
ApplyPatch linux-2.6-cifs-fix-incomplete-rcv.patch
ApplyPatch linux-2.6-cifs-typo-in-cifs_reconnect-fix.patch
ApplyPatch linux-2.6-cifs-fix-bad-handling-of-EAGAIN.patch

# Networking
# Disable easy to trigger printk's.
ApplyPatch linux-2.6-net-silence-noisy-printks.patch
# fix oops in netfilter again
ApplyPatch linux-2.6-netfilter-really-fix-oops-in-nf_nat_move_storage.patch

# madwifi
%if %{build_madwifi}
pushd ../madwifi*
%ifarch ppc
find . -name Makefile\* | xargs perl -pi -e's,/sbin/depmod,: /sbin/depmod,'
%endif
popd
%endif
# end madwifi

# Reiser4
%if %{build_reiser4fs}

ApplyPatch reiser4-for-2.6.23-3.patch.gz

%endif

# ReiserFS
ApplyPatch reiserfs-workaround-for-dead-loop-in-finish_unfinished.patch
ApplyPatch reiserfs-workaround-for-dead-loop-in-finish_unfinished-fix.patch

#%if %{build_nilfs}
# nilfs
#pushd ../nilfs-%{nilfs_ver}
#%patch1450 -p1
#popd
#%endif

%if %{build_btrfs}
pushd ../btrfs-%{btrfs_ver}
popd
%endif

%if %{build_unionfs}
ApplyPatch unionfs-%{unionfs_ver}_for_%{unionfs_kernel_ver}.diff.gz
%endif

# NVIDIA driver
ApplyPatch $(basename %{P:2500})

# SE-200PCI and SE-90PCI drivers
ApplyPatch $(basename %{P:2600})

# MacBook JIS Keyboard
ApplyPatch $(basename %{P:2700})

# Thinkpad-ACPI driver
ApplyPatch $(basename %{P:3000})

# gcc-4.3
ApplyPatch $(basename %{P:3100})

#
# Various SELinux fixes from 2.6.10rc
#

# Misc fixes

# Fix SHA1 alignment problem on ia64
ApplyPatch linux-2.6-sha_alignment.patch
# The input layer spews crap no-one cares about.
ApplyPatch linux-2.6-input-kill-stupid-messages.patch
# Fix loss of sync caused by adding dell Vostro 1400
ApplyPatch linux-2.6-input-fix-sync-loss-acer-aspire.patch
# Add support for new macbook trackpads
ApplyPatch linux-2.6-input-appletouch-macbook3-trackpad.patch
# Allow to use 480600 baud on 16C950 UARTs
ApplyPatch linux-2.6-serial-460800.patch
# add ids for new wacom tablets
ApplyPatch linux-2.6-serial_pnp-add-new-wacom-ids.patch
# Add a safety net to softlockup so that it doesn't prevent installs.
#ApplyPatch linux-2.6-softlockup-disable.patch
# Silence some useless messages that still get printed with 'quiet'
ApplyPatch linux-2.6-silence-noise.patch

# Fix the SELinux mprotect checks on executable mappings
ApplyPatch linux-2.6-selinux-mprotect-checks.patch
# don't leak memory in netlabel code
ApplyPatch linux-2.6-selinux-fix-netlabel-leak.patch
# strip extra leading slashes in pathnames
ApplyPatch linux-2.6-selinux-strip-leading-slashes.patch

# Remove kernel-internal functionality that nothing external should use.
ApplyPatch linux-2.6-unexport-symbols.patch

#
# VM related fixes.
#
# Silence GFP_ATOMIC failures.
ApplyPatch linux-2.6-vm-silence-atomic-alloc-failures.patch
# fix ptrace hang trying to access invalid memory location
ApplyPatch linux-2.6-mm-fix-ptrace-access-beyond-vma.patch
# fix read after direct IO write returning stale data
ApplyPatch linux-2.6-dio-fix-cache-invalidation-after-sync-writes.patch
# restore /proc/slabinfo
ApplyPatch linux-2.6-slub-provide-proc-slabinfo.patch
# fix oops with futex on uniprocessor machine
ApplyPatch linux-2.6-futex-fix-fixups.patch

# Changes to upstream defaults.
# Use UTF-8 by default on VFAT.
ApplyPatch linux-2.6-defaults-fat-utf8.patch
# Use unicode VT's by default.
ApplyPatch linux-2.6-defaults-unicode-vt.patch
# Disable NMI watchdog by default.
ApplyPatch linux-2.6-defaults-nonmi.patch
# Disable PCI MMCONFIG by default.
ApplyPatch linux-2.6-defaults-nommconf.patch

# Disable ATAPI DMA on ALI chipsets.
ApplyPatch linux-2.6-libata-ali-atapi-dma.patch
# ia64 ata quirk
ApplyPatch linux-2.6-ata-quirk.patch
# Enable ACPI ATA objects
ApplyPatch linux-2.6-libata-acpi-enable.patch
# add option to disable PATA DMA
ApplyPatch linux-2.6-libata-add-dma-disable-option.patch
# fix resume failure on some systems
ApplyPatch linux-2.6-libata-dont-fail-revalidation-for-bad-gtf-methods.patch
# serverworks is broken with some drive combinations
ApplyPatch linux-2.6-libata-pata_serverworks-fix-drive-combinations.patch
# fix libata IORDY handling
ApplyPatch linux-2.6-libata-correct-iordy-handling.patch
# fix ATA tape drives
ApplyPatch linux-2.6-libata-tape-max-sectors.patch
ApplyPatch linux-2.6-libata-work-around-drq-1-err-1-for-tapes.patch
ApplyPatch linux-2.6-libata-use-stuck-err-for-tapes.patch
# allow 12-byte SCSI commands for ATAPI devices
# ApplyPatch linux-2.6-libata-scsi-allow-short-commands.patch
# fix ahci reset
ApplyPatch linux-2.6-libata-ahci-enable-ahci-mode-before-reset.patch
# work around broken lba48 disks
ApplyPatch linux-2.6-libata-fix-bogus-lba48-disks.patch

# wireless patches headed for 2.6.24
ApplyPatch linux-2.6-wireless.patch
# wireless patches staged for 2.6.25
ApplyPatch linux-2.6-wireless-pending.patch
# Add misc wireless bits from upstream wireless tree
ApplyPatch linux-2.6-at76.patch
ApplyPatch linux-2.6-rndis_wext.patch
# Make ath5k use software WEP
ApplyPatch linux-2.6-ath5k-use-soft-wep.patch
ApplyPatch linux-2.6.23-GWUS54GXS.patch

# Restore ability to add/remove virtual i/fs to mac80211 devices
ApplyPatch linux-2.6-cfg80211-extras.patch

# add module alias for "zd1211rw-mac80211"
ApplyPatch linux-2.6-zd1211rw-module-alias.patch

# latest Intel driver for ich9
ApplyPatch linux-2.6-netdev-e1000e-01.patch
ApplyPatch linux-2.6-netdev-e1000e-02.patch
ApplyPatch linux-2.6-netdev-e1000e-03.patch
ApplyPatch linux-2.6-netdev-e1000e-04.patch
ApplyPatch linux-2.6-netdev-e1000e-05.patch
ApplyPatch linux-2.6-netdev-e1000e-06.patch
ApplyPatch linux-2.6-netdev-e1000e-07.patch
ApplyPatch linux-2.6-netdev-e1000e-08.patch
ApplyPatch linux-2.6-netdev-e1000e-09.patch
ApplyPatch linux-2.6-netdev-e1000e-10.patch

# Workaround for flaky e1000 EEPROMs
ApplyPatch linux-2.6-e1000-bad-csum-allow.patch
# disable link power savings, should fix bad eeprom checksum too
ApplyPatch linux-2.6-netdev-e1000-disable-alpm.patch
# add atl2 network driver for eeepc
ApplyPatch linux-2.6-netdev-atl2-2.0.3.patch
# spidernet: fix interrupt handling
ApplyPatch linux-2.6-netdev-spidernet-fix-interrupt-handling.patch
# fix station address on meghertz pcmcia adpter (#233255)
ApplyPatch linux-2.6-netdev-smc91c92_cs-fix-station-addr.patch -R

# ACPI/PM patches
# fix EC init
ApplyPatch linux-2.6-acpi-git-ec-init-fixes.patch
# fix multiple ACPI brightness problems (#427518)
ApplyPatch linux-2.6-acpi-video-backlight-rationalize.patch
ApplyPatch linux-2.6-acpi-video-brightness-bigger-buffer.patch
ApplyPatch linux-2.6-acpi-video-fix-multiple-busses.patch
# fix date/time display when using PM_TRACE
ApplyPatch linux-2.6-pmtrace-time-fix.patch
# Send button state on create / resume
ApplyPatch linux-2.6-acpi-button-send-initial-state.patch
# fix cpuidle regressions
ApplyPatch linux-2.6-acpi-cpuidle-0-upstream.patch
ApplyPatch linux-2.6-acpi-cpuidle-1-fix-C3-for-no-bm-ctrl.patch
ApplyPatch linux-2.6-acpi-cpuidle-2-fix-HP-nx6125-regression.patch
# fix EC init
ApplyPatch linux-2.6-acpi-dont-init-ec-early-with-no-ini.patch
# Eeepc hotkey driver
ApplyPatch linux-2.6-acpi-eeepc-hotkey.patch
# fix EC init fix
ApplyPatch linux-2.6-acpi_ec_early_init_fix.patch

# Fix excessive wakeups
# Make hdaps timer only tick when in use.
ApplyPatch linux-2.6-wakeups-hdaps.patch
ApplyPatch linux-2.6-wakeups.patch

# dm / md
  	 
# ACPI

# USB
# Do USB suspend only on certain classes of device.
ApplyPatch linux-2.6-usb-suspend-classes.patch
# initialize strange modem/storage device properly (from F7 kernel)
ApplyPatch linux-2.6-usb-storage-initialize-huawei-e220-properly.patch
ApplyPatch linux-2.6-usb-huawei-fix-init-in-modem-mode.patch

# some usb disks spin down automatically and need allow_restart
ApplyPatch linux-2.6-usb-storage-always-set-the-allow_restart-flag.patch

# implement smarter atime updates support.
ApplyPatch linux-2.6-smarter-relatime.patch

# xfs bugfixes & stack reduction
ApplyPatch linux-2.6-xfs-optimize-away-dmapi-tests.patch
ApplyPatch linux-2.6-xfs-optimize-away-realtime-tests.patch
ApplyPatch linux-2.6-xfs-refactor-xfs_mountfs.patch
ApplyPatch linux-2.6-xfs-setfattr-32bit-compat.patch

# ivtv
%if %{build_ivtv}
pushd ../ivtv-%{ivtv_ver}
perl -pi -e 's,/sbin/depmod,:,g' driver/Makefile
popd
%endif


#
# misc small stuff to make things compile or otherwise improve performance

C=$(wc -l $RPM_SOURCE_DIR/linux-2.6-compile-fixes.patch | awk '{print $1}')
if [ "$C" -gt 10 ]; then
ApplyPatch linux-2.6-compile-fixes.patch
fi


# build id related enhancements
ApplyPatch linux-2.6-add-mmf_dump_elf_headers.patch
ApplyPatch linux-2.6-default-mmf_dump_elf_headers.patch
ApplyPatch linux-2.6-add-sys-module-name-notes.patch
ApplyPatch linux-2.6-i386-vdso-install-unstripped-copies-on-disk.patch
ApplyPatch linux-2.6-powerpc-vdso-install-unstripped-copies-on-disk.patch
ApplyPatch linux-2.6-x86_64-ia32-vdso-install-unstripped-copies-on-disk.patch
ApplyPatch linux-2.6-x86_64-vdso-install-unstripped-copies-on-disk.patch
ApplyPatch linux-2.6-pass-g-to-assembler-under-config_debug_info.patch
ApplyPatch linux-2.6-powerpc-lparmap-g.patch

# http://www.lirc.org/
ApplyPatch linux-2.6-lirc.patch

# DMI autoloading for dcdbas driver
ApplyPatch linux-2.6-dcdbas-autoload.patch

# FireWire updates and fixes
ApplyPatch linux-2.6-firewire-git-update.patch

ApplyPatch linux-2.6-net-e100-disable-polling.patch
ApplyPatch linux-2.6-thinkpad-key-events.patch

# ---------- below all scheduled for 2.6.24 -----------------

# SELinux perf patches
ApplyPatch linux-2.6-selinux-no-revalidate-read-write.patch
ApplyPatch linux-2.6-selinux-ebitmap-for-avc-miss.patch
ApplyPatch linux-2.6-selinux-ebitmap-for-avc-miss-cleanup.patch
ApplyPatch linux-2.6-selinux-sigchld-wait.patch
ApplyPatch linux-2.6-selinux-ebitmap-loop-bug.patch

# removed in 2.6.23.10
# ApplyPatch linux-2.6-freezer-fix-apm-emulation-breakage.patch

# END OF PATCH APPLICATIONS

%endif

# Any further pre-build tree manipulations happen here.

chmod +x scripts/checkpatch.pl

cp %{SOURCE10} Documentation/

mkdir configs

cp -f %{all_arch_configs} .

%if ! %{debugbuildsenabled}
rm -f kernel-%{kversion}-*-debug.config
%endif

# now run oldconfig over all the config files
for i in *.config
do
  mv $i .config
  Arch=`head -1 .config | cut -b 3-`
  make ARCH=$Arch nonint_oldconfig > /dev/null
  echo "# $Arch" > configs/$i
  cat .config >> configs/$i
done

# make sure the kernel has the sublevel we know it has. This looks weird
# but for -pre and -rc versions we need it since we only want to use
# the higher version when the final kernel is released.
perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile
#perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -prep/" Makefile

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -exec rm -f {} \; >/dev/null

cd ..

# Unpack the Xen tarball.
%if %{includexen}
cp %{SOURCE2} .
if [ -d xen ]; then
  rm -rf xen
fi
%setup -D -T -q -n kernel-%{version} -a1
cd xen
# Any necessary hypervisor patches go here

%endif


###
### build
###
%build

%if %{usesparse}
%global sparse_mflags	C=1
%endif

#
# Create gpg keys for signing the modules
#
%if %{signmodules}
gpg --homedir . --batch --gen-key %{SOURCE11}
gpg --homedir . --export --keyring ./kernel.pub Red > extract.pub
make linux-%{kversion}.%{_target_cpu}/scripts/bin2c
linux-%{kversion}.%{_target_cpu}/scripts/bin2c ksign_def_public_key __initdata < extract.pub > linux-%{kversion}.%{_target_cpu}/crypto/signature/key.h
%endif

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    Flavour=$3

    # Pick the right config file for the kernel we're building
    if [ -n "$Flavour" ] ; then
      Config=kernel-%{kversion}-%{_target_cpu}-$Flavour.config
      DevelDir=/usr/src/kernels/%{KVERREL}-$Flavour-%{_target_cpu}
      DevelLink=/usr/src/kernels/%{KVERREL}$Flavour-%{_target_cpu}
    else
      Config=kernel-%{kversion}-%{_target_cpu}.config
      DevelDir=/usr/src/kernels/%{KVERREL}-%{_target_cpu}
      DevelLink=
    fi

    KernelVer=%{version}-%{release}$Flavour
    echo BUILDING A KERNEL FOR $Flavour %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}$Flavour/" Makefile

    # and now to start the build process

    make -s mrproper
    cp configs/$Config .config

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

    if [ "$KernelImage" == "x86" ]; then
       KernelImage=arch/$Arch/boot/bzImage
    fi

    make -s ARCH=$Arch nonint_oldconfig > /dev/null
    make -s ARCH=$Arch %{?_smp_mflags} $MakeTarget %{?sparse_mflags}
    make -s ARCH=$Arch %{?_smp_mflags} modules %{?sparse_mflags} || exit 1

    # Start installing the results

%if "%{_enable_debug_packages}" == "1"
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/boot
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/%{image_install_path}
%endif
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    touch $RPM_BUILD_ROOT/boot/initrd-$KernelVer.img
    cp $KernelImage $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-$KernelVer
    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
    fi

    if [ "$Flavour" == "kdump" ]; then
        cp vmlinux $RPM_BUILD_ROOT/%{image_install_path}/vmlinux-$KernelVer
        rm -f $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-$KernelVer
    fi

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    make -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer

    # Create the kABI metadata for use in packaging
#   echo "**** GENERATING kernel ABI metadata ****"
#   gzip -c9 < Module.symvers > $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz
#   chmod 0755 %_sourcedir/kabitool
#   if [ ! -e $RPM_SOURCE_DIR/kabi_whitelist ]; then
#       %_sourcedir/kabitool -b $RPM_BUILD_ROOT/$DevelDir -k $KernelVer -l $RPM_BUILD_ROOT/kabi_whitelist
#   else
#       cp $RPM_SOURCE_DIR/kabi_whitelist $RPM_BUILD_ROOT/kabi_whitelist
#   fi
#   rm -f %{_tmppath}/kernel-$KernelVer-kabideps
#    %_sourcedir/kabitool -b . -d %{_tmppath}/kernel-$KernelVer-kabideps -k $KernelVer -w $RPM_BUILD_ROOT/kabi_whitelist

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/extra
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
#    mv $RPM_BUILD_ROOT/kabi_whitelist $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
#    cp symsets-$KernelVer.tar.gz $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp arch/%{_arch}/kernel/asm-offsets.s $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/kernel || :
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -d arch/%{_arch}/scripts ]; then
      cp -a arch/%{_arch}/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/%{_arch}/*lds ]; then
      cp -a arch/%{_arch}/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cd include
    cp -a acpi config keys linux math-emu media mtd net pcmcia rdma rxrpc scsi sound video asm asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp -a `readlink asm` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    if [ "$Arch" = "x86_64" ]; then
      cp -a asm-i386 $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    fi
    # While arch/powerpc/include/asm is still a symlink to the old
    # include/asm-ppc{64,} directory, include that in kernel-devel too.
    if [ "$Arch" = "powerpc" -a -r ../arch/powerpc/include/asm ]; then
      cp -a `readlink ../arch/powerpc/include/asm` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
      mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/$Arch/include
      pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/$Arch/include
      ln -sf ../../../include/asm-ppc* asm
      popd
    fi
%if %{includexen}
    cp -a xen $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
%endif

    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/version.h
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/autoconf.h
    # Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
    cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf
    cd ..

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
%if "%{_enable_debug_packages}" == "1"
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # gpg sign the modules
%if %{signmodules}
    gcc -o scripts/modsign/mod-extract scripts/modsign/mod-extract.c -Wall
    KEYFLAGS="--no-default-keyring --homedir .."
    KEYFLAGS="$KEYFLAGS --secret-keyring ../kernel.sec"
    KEYFLAGS="$KEYFLAGS --keyring ../kernel.pub"
    export KEYFLAGS

    for i in `cat modnames`
    do
      sh ./scripts/modsign/modsign.sh $i Red
      mv -f $i.signed $i
    done
    unset KEYFLAGS
%endif
    # mark modules executable so that strip-to-file can strip them
    cat modnames | xargs chmod u+x

    # Generate a list of modules for SCSI, sata/pata, and networking.
    touch $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.scsi
    touch $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.libata
    touch $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.networking
    for i in `cat modnames | grep drivers | grep -v drivers\/ata`
    do
      if [ $(nm $i |grep --count scsi_add_host) -ne 0 ];
      then
        basename `echo $i` >> $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.scsi
      fi
    done

    for i in `cat modnames | grep drivers\/ata`
    do
      if [ $(nm $i |grep --count ata_device_add) -ne 0 -o $(nm $i |grep --count ata_pci_init_one) -ne 0 ];
      then
        basename `echo $i` >> $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.libata
      fi
    done

    for i in `cat modnames |grep drivers`
    do
      if [ $(nm $i |grep --count register_netdev) -ne 0 ];
      then
        basename `echo $i` >> $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.networking
      fi
    done

    # detect missing or incorrect license tags
    for i in `cat modnames`
    do
      echo -n "$i "
      /sbin/modinfo -l $i >> modinfo
    done
    cat modinfo |\
      grep -v "^GPL" |
      grep -v "^Dual BSD/GPL" |\
      grep -v "^Dual MPL/GPL" |\
      grep -v "^GPL and additional rights" |\
      grep -v "^GPL v2" && exit 1
    rm -f modinfo
    rm -f modnames
    # remove files that will be auto generated by depmod at rpm -i time
    for i in alias ccwmap dep ieee1394map inputmap isapnpmap ofmap pcimap seriomap symbols usbmap
    do
      rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$i
    done

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir
    ln -sf ../../..$DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    [ -z "$DevelLink" ] || ln -sf `basename $DevelDir` $RPM_BUILD_ROOT/$DevelLink

%ifarch %{ix86} x86_64 ppc
    # madwifi
%if %{build_madwifi}
    if [ "$Flavour" != "xenU" ]; then
      cd ../madwifi*
%ifarch ppc
      export TARGET=powerpc-be-eabi
      export KERNELRELEASE=%{rpmversion}-%{rel}
      export TOOLPREFIX='/usr/bin/'
%endif
      make modules KERNELPATH=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu}
      make install-modules DESTDIR=%{buildroot} KERNELPATH=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu} KERNELCONF=%{buildroot}/lib/modules/$KernelVer/build/.config KERNELRELEASE=$KernelVer KMODPATH=/lib/modules/$KernelVer/kernel/drivers/net/wireless/madwifi
      cd -
    fi
%endif
%endif

%if %{build_iwlwifi}
%ifarch %{ix86} x86_64
    # iwlwifi
    if [ "$Flavour" != "xenU" ]; then
      cd ../iwlwifi-%{iwlwifi_ver}/
      make clean
      perl -pi -e's,/sbin/depmod,:,g' Makefile
      make KSRC=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu} IEEE80211_INC=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu}/include/ -i
      make KSRC=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu} IEEE80211_INC=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu}/include/
      make KSRC=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu} IEEE80211_INC=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu}/include/ KMISC=%{buildroot}/lib/modules/$KernelVer/kernel/drivers/net/wireless/ install
      cd -
    fi
%endif
%endif

%ifarch %{ix86} x86_64
%if %{build_nilfs}
    # nilfs
    cd ../nilfs-%{nilfs_ver}/fs
    perl -pi -e "s,/sbin/depmod,:,g" Makefile
    make clean
    make KSRC=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu} MDIR=%{buildroot}/lib/modules/$KernelVer/kernel/fs/nilfs/ KVER="%{kversion}-%{release}"
    make install KSRC=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu} MDIR=%{buildroot}/lib/modules/$KernelVer/kernel/fs/nilfs/ KVER="%{kversion}-%{release}"
    cd -
%endif
%endif

%ifarch %{ix86} x86_64
%if %{build_btrfs}
    # btrfs
    cd ../btrfs-%{btrfs_ver}
    make KERNELDIR=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu} 
    mkdir -p %{buildroot}/lib/modules/$KernelVer/kernel/fs/btrfs
    install -m 644 -c btrfs.ko %{buildroot}/lib/modules/$KernelVer/kernel/fs/btrfs/
    cd -
%endif
%endif

%ifarch %{ix86} x86_64
    # ivtv
    %if %{build_ivtv}
    if [ "$Flavour" != "xenU" ]; then
      cd ../ivtv-%{ivtv_ver}
        make -C driver KDIR=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu}
        make modules_install INSTALL_MOD_PATH=%{buildroot} INSTALL_MOD_DIR=kernel/drivers/media/video/ivtv -C %{buildroot}/lib/modules/$KernelVer/build M=%{_builddir}/kernel-%{kversion}/ivtv-%{ivtv_ver}/driver
        make -C i2c-drivers KDIR=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu}
        make modules_install INSTALL_MOD_PATH=%{buildroot} INSTALL_MOD_DIR=kernel/drivers/media/video -C %{buildroot}/lib/modules/$KernelVer/build M=%{_builddir}/kernel-%{kversion}/ivtv-%{ivtv_ver}/i2c-drivers
      cd -
    fi
    %endif
%endif

}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot

%if %{includexen}
%if %{buildxen}
  cd xen
  mkdir -p $RPM_BUILD_ROOT/%{image_install_path} $RPM_BUILD_ROOT/boot
  make %{?_smp_mflags} %{xen_flags}
  install -m 644 xen.gz $RPM_BUILD_ROOT/%{image_install_path}/xen.gz-%{KVERREL}
  install -m 755 xen-syms $RPM_BUILD_ROOT/boot/xen-syms-%{KVERREL}
  cd ..
%endif
%endif

cd linux-%{kversion}.%{_target_cpu}

%if %{debugbuildsenabled}
%if %{builddebug}
BuildKernel %make_target %kernel_image debug
%if %{buildpae}
BuildKernel %make_target %kernel_image PAE-debug
%endif
%endif
%endif

%if %{buildpae}
BuildKernel %make_target %kernel_image PAE
%endif

%if %{buildup}
BuildKernel %make_target %kernel_image
%endif

%if %{buildsmp}
BuildKernel %make_target %kernel_image smp
%endif

%if %{includexen}
%if %{buildxen}
BuildKernel %xen_target %xen_image xen
%endif
%endif

%if %{buildkdump}
BuildKernel %make_target %kernel_image kdump
%endif

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must reglobal it before that.
%global debug_package %{nil}

%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%global __debug_package 1
%files debuginfo-common
%defattr(-,root,root)
/usr/src/debug/%{name}-%{version}/linux-%{kversion}.%{_target_cpu}
%if %{includexen}
%if %{buildxen}
/usr/src/debug/%{name}-%{version}/xen
%endif
%endif
%dir /usr/src/debug
%dir /usr/lib/debug
%dir /usr/lib/debug/%{image_install_path}
%dir /usr/lib/debug/lib
%dir /usr/lib/debug/lib/modules
%dir /usr/lib/debug/usr/src/kernels
%endif
%endif

###
### install
###

%install

cd linux-%{kversion}.%{_target_cpu}

%if %{includexen}
%if %{buildxen}
mkdir -p $RPM_BUILD_ROOT/etc/ld.so.conf.d
rm -f $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf
cat > $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf <<\EOF
# This directive teaches ldconfig to search in nosegneg subdirectories
# and cache the DSOs there with extra bit 0 set in their hwcap match
# fields.  In Xen guest kernels, the vDSO tells the dynamic linker to
# search in nosegneg subdirectories and to match this extra hwcap bit
# in the ld.so.cache file.
hwcap 0 nosegneg
EOF
chmod 444 $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf
%endif
%endif

%if %{builddoc}
mkdir -p $RPM_BUILD_ROOT/usr/share/doc/kernel-doc-%{kversion}/Documentation

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a+r *
# copy the source over
tar cf - Documentation | tar xf - -C $RPM_BUILD_ROOT/usr/share/doc/kernel-doc-%{kversion}
%endif

%if %{buildheaders}
# Install kernel headers
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

# Manually go through the 'headers_check' process for every file, but
# don't die if it fails
chmod +x scripts/hdrcheck.sh
echo -e '*****\n*****\nHEADER EXPORT WARNINGS:\n*****' > hdrwarnings.txt
for FILE in `find $RPM_BUILD_ROOT/usr/include` ; do
    scripts/hdrcheck.sh $RPM_BUILD_ROOT/usr/include $FILE /dev/null >> hdrwarnings.txt || :
done
echo -e '*****\n*****' >> hdrwarnings.txt
if grep -q exist hdrwarnings.txt; then
   sed s:^$RPM_BUILD_ROOT/usr/include/:: hdrwarnings.txt
   # Temporarily cause a build failure if header inconsistencies.
   # exit 1
fi

# glibc provides scsi headers for itself, for now
rm -rf $RPM_BUILD_ROOT/usr/include/scsi
rm -f $RPM_BUILD_ROOT/usr/include/asm*/atomic.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/io.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/irq.h
%endif
###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

%post
if [ `uname -i` == "x86_64" -o `uname -i` == "i386" ]; then
  if [ -f /etc/sysconfig/kernel ]; then
    /bin/sed -i -e 's/^DEFAULTKERNEL=kernel-smp$/DEFAULTKERNEL=kernel/' /etc/sysconfig/kernel
  fi
fi
[ ! -x /usr/sbin/module_upgrade ] || /usr/sbin/module_upgrade %{rpmversion}-%{release}
/sbin/new-kernel-pkg --package kernel --mkinitrd --depmod --install %{KVERREL}

%post devel
if [ -f /etc/sysconfig/kernel ]
then
    . /etc/sysconfig/kernel || exit $?
fi
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*mo*-*/$f $f ; done
  popd > /dev/null
fi

%post smp
[ ! -x /usr/sbin/module_upgrade ] || /usr/sbin/module_upgrade %{rpmversion}-%{release}smp
/sbin/new-kernel-pkg --package kernel-smp --mkinitrd --depmod --install %{KVERREL}smp

%post smp-devel
if [ -f /etc/sysconfig/kernel ]
then
    . /etc/sysconfig/kernel || exit $?
fi
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-smp-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*mo*-*/$f $f ; done
  popd > /dev/null
fi

%post PAE
if [ -f /etc/sysconfig/kernel ]; then
    /bin/sed -i -e 's/^DEFAULTKERNEL=kernel-smp$/DEFAULTKERNEL=kernel-PAE/' /etc/sysconfig/kernel
fi
/sbin/new-kernel-pkg --package kernel-PAE --mkinitrd --depmod --install %{KVERREL}PAE || exit $?
#if [ -x /sbin/weak-modules ]
#then
#    /sbin/weak-modules --add-kernel %{KVERREL}PAE || exit $?
#fi

%post PAE-devel
if [ -f /etc/sysconfig/kernel ]
then
    . /etc/sysconfig/kernel || exit $?
fi
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-PAE-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*mo*-*/$f $f ; done
  popd > /dev/null
fi

%if %{debugbuildsenabled}
%if %{builddebug}
%post debug
/sbin/new-kernel-pkg --package kernel-debug --mkinitrd --depmod --install %{KVERREL}debug || exit $?
#if [ -x /sbin/weak-modules ]
#then
#    /sbin/weak-modules --add-kernel %{KVERREL}debug || exit $?
#fi

%post debug-devel
if [ -f /etc/sysconfig/kernel ]
then
    . /etc/sysconfig/kernel || exit $?
fi
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-debug-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*mo*-*/$f $f ; done
  popd > /dev/null
fi

%post PAE-debug
if [ -f /etc/sysconfig/kernel ]; then
    /bin/sed -i -e 's/^DEFAULTKERNEL=kernel-smp$/DEFAULTKERNEL=kernel-PAE/' /etc/sysconfig/kernel
fi
/sbin/new-kernel-pkg --package kernel-PAE --mkinitrd --depmod --install %{KVERREL}PAE-debug || exit $?
#if [ -x /sbin/weak-modules ]
#then
#    /sbin/weak-modules --add-kernel %{KVERREL}PAE || exit $?
#fi

%post PAE-debug-devel
if [ -f /etc/sysconfig/kernel ]
then
    . /etc/sysconfig/kernel || exit $?
fi
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-PAE-debug-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*mo*-*/$f $f ; done
  popd > /dev/null
fi
%endif
%endif

%post xen
if [ `uname -i` == "x86_64" -o `uname -i` == "i386" ]; then
  if [ -f /etc/sysconfig/kernel ]; then
    /bin/sed -i -e 's/^DEFAULTKERNEL=kernel-xen[0U]/DEFAULTKERNEL=kernel-xen/' /etc/sysconfig/kernel || exit $?
  fi
fi
if [ -e /proc/xen/xsd_kva -o ! -d /proc/xen ]; then
	/sbin/new-kernel-pkg --package kernel-xen --mkinitrd --depmod --install --multiboot=/%{image_install_path}/xen.gz-%{KVERREL} %{KVERREL}xen || exit $?
else
	/sbin/new-kernel-pkg --package kernel-xen --mkinitrd --depmod --install %{KVERREL}xen || exit $?
fi
if [ -x /sbin/ldconfig ]
then
    /sbin/ldconfig -X || exit $?
fi
#if [ -x /sbin/weak-modules ]
#then
#    /sbin/weak-modules --add-kernel %{KVERREL}xen || exit $?
#fi

%post xen-devel
if [ -f /etc/sysconfig/kernel ]
then
    . /etc/sysconfig/kernel || exit $?
fi
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-xen-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*mo*-*/$f $f ; done
  popd > /dev/null
fi

%post kdump
[ ! -x /usr/sbin/module_upgrade ] || /usr/sbin/module_upgrade %{rpmversion}-%{release}-kdump
/sbin/new-kernel-pkg --package kernel-kdump --mkinitrd --depmod --install %{KVERREL}kdump

%post kdump-devel
[ -f /etc/sysconfig/kernel ] && . /etc/sysconfig/kernel
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-kdump-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*mo*-*/$f $f ; done
  popd > /dev/null
fi

%preun
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}

%preun smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}smp
%preun PAE
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}PAE

%preun kdump
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}kdump
%if %{debugbuildsenabled}
%if %{builddebug}
%preun debug
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}debug
if [ -x /sbin/weak-modules ]
then
    /sbin/weak-modules --remove-kernel %{KVERREL}debug || exit $?
fi
%preun PAE-debug
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}debug
%endif
%endif

%preun xen
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}xen

###
### file lists
###

# This is %{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%global elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

%if %{buildup}
%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%files debuginfo
%defattr(-,root,root)
%if "%{elf_image_install_path}" != ""
/usr/lib/debug/%{elf_image_install_path}/*-%{KVERREL}.debug
%endif
/usr/lib/debug/lib/modules/%{KVERREL}
/usr/lib/debug/usr/src/kernels/%{KVERREL}-%{_target_cpu}
%endif
%endif

%files
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}
/boot/System.map-%{KVERREL}
/boot/config-%{KVERREL}
%dir /lib/modules/%{KVERREL}
/lib/modules/%{KVERREL}/kernel
/lib/modules/%{KVERREL}/build
/lib/modules/%{KVERREL}/source
/lib/modules/%{KVERREL}/extra
/lib/modules/%{KVERREL}/updates
/lib/modules/%{KVERREL}/modules.scsi
/lib/modules/%{KVERREL}/modules.libata
/lib/modules/%{KVERREL}/modules.networking
%ghost /boot/initrd-%{KVERREL}.img

%files devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-%{_target_cpu}
%endif

%if %{buildheaders}
%files headers
%defattr(-,root,root)
/usr/include/*
%endif

%if %{debugbuildsenabled}
%if %{builddebug}
%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%files debug-debuginfo
%defattr(-,root,root)
%if "%{elf_image_install_path}" != ""
/usr/lib/debug/%{elf_image_install_path}/*-%{KVERREL}debug.debug
%endif
/usr/lib/debug/lib/modules/%{KVERREL}debug
/usr/lib/debug/usr/src/kernels/%{KVERREL}-debug-%{_target_cpu}
%endif
%endif

%files debug
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}debug
/boot/System.map-%{KVERREL}debug
#/boot/symvers-%{KVERREL}debug.gz
/boot/config-%{KVERREL}debug
%dir /lib/modules/%{KVERREL}debug
/lib/modules/%{KVERREL}debug/kernel
/lib/modules/%{KVERREL}debug/build
/lib/modules/%{KVERREL}debug/source
/lib/modules/%{KVERREL}debug/extra
/lib/modules/%{KVERREL}debug/updates
/lib/modules/%{KVERREL}debug/weak-updates
/lib/modules/%{KVERREL}debug/modules.scsi
/lib/modules/%{KVERREL}debug/modules.libata
/lib/modules/%{KVERREL}debug/modules.networking
%ghost /boot/initrd-%{KVERREL}debug.img

%files debug-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-debug-%{_target_cpu}
/usr/src/kernels/%{KVERREL}debug-%{_target_cpu}
%endif
%endif



%if %{buildpae}
%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%files PAE-debuginfo
%defattr(-,root,root)
%if "%{elf_image_install_path}" != ""
/usr/lib/debug/%{elf_image_install_path}/*-%{KVERREL}PAE.debug
%endif
/usr/lib/debug/lib/modules/%{KVERREL}PAE
/usr/lib/debug/usr/src/kernels/%{KVERREL}-PAE-%{_target_cpu}
%endif
%endif

%files PAE
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}PAE
/boot/System.map-%{KVERREL}PAE
#/boot/symvers-%{KVERREL}PAE.gz
/boot/config-%{KVERREL}PAE
%dir /lib/modules/%{KVERREL}PAE
/lib/modules/%{KVERREL}PAE/kernel
/lib/modules/%{KVERREL}PAE/build
/lib/modules/%{KVERREL}PAE/source
/lib/modules/%{KVERREL}PAE/extra
/lib/modules/%{KVERREL}PAE/updates
/lib/modules/%{KVERREL}PAE/weak-updates
/lib/modules/%{KVERREL}PAE/modules.scsi
/lib/modules/%{KVERREL}PAE/modules.libata
/lib/modules/%{KVERREL}PAE/modules.networking
%ghost /boot/initrd-%{KVERREL}PAE.img

%files PAE-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-PAE-%{_target_cpu}
/usr/src/kernels/%{KVERREL}PAE-%{_target_cpu}

%if %{debugbuildsenabled}
%if %{builddebug}
%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%files PAE-debug-debuginfo
%defattr(-,root,root)
%if "%{elf_image_install_path}" != ""
/usr/lib/debug/%{elf_image_install_path}/*-%{KVERREL}PAE-debug.debug
%endif
/usr/lib/debug/lib/modules/%{KVERREL}PAE-debug
/usr/lib/debug/usr/src/kernels/%{KVERREL}-PAE-debug-%{_target_cpu}
%endif
%endif

%files PAE-debug
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}PAE-debug
/boot/System.map-%{KVERREL}PAE-debug
#/boot/symvers-%{KVERREL}PAE-debug.gz
/boot/config-%{KVERREL}PAE-debug
%dir /lib/modules/%{KVERREL}PAE-debug
/lib/modules/%{KVERREL}PAE-debug/kernel
/lib/modules/%{KVERREL}PAE-debug/build
/lib/modules/%{KVERREL}PAE-debug/source
/lib/modules/%{KVERREL}PAE-debug/extra
/lib/modules/%{KVERREL}PAE-debug/updates
/lib/modules/%{KVERREL}PAE-debug/weak-updates
/lib/modules/%{KVERREL}PAE-debug/modules.scsi
/lib/modules/%{KVERREL}PAE-debug/modules.libata
/lib/modules/%{KVERREL}PAE-debug/modules.networking
%ghost /boot/initrd-%{KVERREL}PAE-debug.img

%files PAE-debug-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-PAE-debug-%{_target_cpu}
/usr/src/kernels/%{KVERREL}PAE-debug-%{_target_cpu}
%endif
%endif
# PAE
%endif


%if %{buildsmp}
%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%files smp-debuginfo
%defattr(-,root,root)
%if "%{elf_image_install_path}" != ""
/usr/lib/debug/%{elf_image_install_path}/*-%{KVERREL}smp.debug
%endif
/usr/lib/debug/lib/modules/%{KVERREL}smp
/usr/lib/debug/usr/src/kernels/%{KVERREL}-smp-%{_target_cpu}
%endif
%endif

%files smp
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}smp
/boot/System.map-%{KVERREL}smp
#/boot/symvers-%{KVERREL}smp.gz
/boot/config-%{KVERREL}smp
%dir /lib/modules/%{KVERREL}smp
/lib/modules/%{KVERREL}smp/kernel
/lib/modules/%{KVERREL}smp/build
/lib/modules/%{KVERREL}smp/source
/lib/modules/%{KVERREL}smp/extra
/lib/modules/%{KVERREL}smp/updates
/lib/modules/%{KVERREL}smp/weak-updates
/lib/modules/%{KVERREL}smp/modules.scsi
/lib/modules/%{KVERREL}smp/modules.libata
/lib/modules/%{KVERREL}smp/modules.networking
%ghost /boot/initrd-%{KVERREL}smp.img

%files smp-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-smp-%{_target_cpu}
/usr/src/kernels/%{KVERREL}smp-%{_target_cpu}
%endif


%if %{includexen}
%if %{with_xen}
%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%files xen-debuginfo
%defattr(-,root,root)
%if "%{elf_image_install_path}" != ""
/usr/lib/debug/%{elf_image_install_path}/*-%{KVERREL}xen.debug
%endif
/usr/lib/debug/lib/modules/%{KVERREL}xen
/usr/lib/debug/usr/src/kernels/%{KVERREL}-xen-%{_target_cpu}
/usr/lib/debug/boot/xen*-%{KVERREL}.debug
%endif
%endif

%files xen
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}xen
/boot/System.map-%{KVERREL}xen
/boot/config-%{KVERREL}xen
/%{image_install_path}/xen.gz-%{KVERREL}
/boot/xen-syms-%{KVERREL}
%dir /lib/modules/%{KVERREL}xen
/lib/modules/%{KVERREL}xen/kernel
%verify(not mtime) /lib/modules/%{KVERREL}xen/build
/lib/modules/%{KVERREL}xen/source
/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf
/lib/modules/%{KVERREL}xen/extra
/lib/modules/%{KVERREL}xen/updates
/lib/modules/%{KVERREL}xen/modules.scsi
/lib/modules/%{KVERREL}xen/modules.libata
/lib/modules/%{KVERREL}xen/modules.networking
%ghost /boot/initrd-%{KVERREL}xen.img

%files xen-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-xen-%{_target_cpu}
/usr/src/kernels/%{KVERREL}xen-%{_target_cpu}
%endif
%endif

%if %{buildkdump}
%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%files kdump-debuginfo
%defattr(-,root,root)
%if "%{image_install_path}" != ""
/usr/lib/debug/%{image_install_path}/*-%{KVERREL}kdump.debug
%endif
/usr/lib/debug/lib/modules/%{KVERREL}kdump
/usr/lib/debug/usr/src/kernels/%{KVERREL}-kdump-%{_target_cpu}
%endif
%endif

%files kdump
%defattr(-,root,root)
/%{image_install_path}/vmlinux-%{KVERREL}kdump
/boot/System.map-%{KVERREL}kdump
/boot/config-%{KVERREL}kdump
%dir /lib/modules/%{KVERREL}kdump
/lib/modules/%{KVERREL}kdump/kernel
/lib/modules/%{KVERREL}kdump/build
/lib/modules/%{KVERREL}kdump/source
/lib/modules/%{KVERREL}kdump/extra
/lib/modules/%{KVERREL}kdump/updates
/lib/modules/%{KVERREL}kdump/modules.scsi
/lib/modules/%{KVERREL}kdump/modules.libata
/lib/modules/%{KVERREL}kdump/modules.networking
%ghost /boot/initrd-%{KVERREL}kdump.img

%files kdump-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-kdump-%{_target_cpu}
/usr/src/kernels/%{KVERREL}kdump-%{_target_cpu}
%endif

# only some architecture builds need kernel-doc

%if %{builddoc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{kversion}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{kversion}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{kversion}
%endif

%changelog
* Fri Feb 15 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-48m)
- gcc-4.3 fix 
-- Patch3100: linux-2.6-compile-fix-gcc-43.patch

* Fri Feb 15 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-47m)
- update 2.6.23.16
- update nilfs-2.0-test9
- update thinkpad-acpi-0.19-20080213_v2.6.23.16
- import Fedora Patch(2_6_23_14-137_fc8)

* Thu Feb  7 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-46m)
- update madwifi-ng-r3344-20080207
- update btrfs-0.12
- import Fedora Patch(2_6_23_14-135_fc8)

* Wed Jan 30 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-45m)
- update unionfs-2.2.3
- import Fedora Patch(2_6_23_14-123_fc8)

* Sat Jan 26 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-44m)
- update madwifi-ng-r3233-20080123
- import Fedora Patch(2_6_23_14-119_fc8)

* Sat Jan 19 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-43m)
- update madwifi-r3191-20080117
- update btrfs-0.11 

* Wed Jan 16 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-42m)
- update kernel-2.6.23.14
- update sched-cfs-v2.6.23.12-v24.1(2nd) 

* Sun Jan 13 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-41m)
- update madwifi-r3122-20080111
- import Fedora Patch(2_6_23_12-106_fc8)

* Thu Jan 10 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-40m)
- update kernel-2.6.23.13
- update thinkpad-acpi-0.19-20080107
- update unionfs-2.2.2

* Wed Jan  9 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-39m)
- update reiser4-for-2.6.23-3.patch
- update unionfs-2.2.1
- update madwifi-r3122-20080109
- import Fedora Patch(2_6_23_12-102_fc8)

* Wed Jan  3 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-38m)
- update reiser4-for-2.6.23-2
- update unionfs-2.2
- update nilfs-2.0-test8

* Mon Dec 24 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-37m)
- update linux-2.6.23.12
- update sched-cfs-v2.6.23.12-v24.1
- update madwifi-ng r3077-20071224
- import Fedora Patch(2_6_23_12-100_fc8)

* Mon Dec 17 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-36m)
- update linux-2.6.23.11
- fix kernel-2.6.23-i686-PAE-debug.config
- import Fedora Patch(2_6_23_10-97_fc8)

* Mon Dec 17 2007 Masanobu Sato <satoshiga@momonga-linux.org>
- (2.6.23-35m)
- add patch for GWUS54GXS of USB Wireless Adapter
-- http://www.planex.co.jp/product/wireless/gw-us54gxs.shtml
- add patch for fixing bug in device_rename()
-- http://groups.google.co.jp/group/linux.kernel/msg/6f4cc060209f3cd1
- modified *i686*.config for enabling ZD1211RW

* Sun Dec 15 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-34m)
- use official reiser4 patch
-- http://chichkin_i.zelnet.ru/namesys/reiser4-for-2.6.23.patch.gz
- update madwifi-ng-r3053-20071214
- import Fedora Patch

* Mon Dec 10 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-33m)
- import Fedora Patch
- update thinkpad-acpi-0.13-20071203
- update unionfs-2.1.11
- update madwifi-ng-r3008-20071208

* Thu Dec  6 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-32m)
- add AMD Phenom rev.B2 Eratta patch
-- https://www.x86-64.org/pipermail/discuss/2007-December/010260.html

* Wed Dec  5 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-31m)
- import Fedora Patches
- update btrfs-0.9

* Sun Dec  2 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-30m)
- update madwifi-ng-r2992-20071130
- fix kernel-debug %%post error

* Sat Dec  1 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-29m)
- import Fedora Patches
- update TuxOnIce-3.0-rc3

* Thu Nov 29 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.23-28m)
- update nilfs-2.0.0-testing-7

* Tue Nov 27 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-27m)
- update 2.6.23.8
- update unionfs-2.1.10

* Fri Nov 23 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-26m)
- update sched-cfs-v2.6.23.8-v24

* Thu Nov 22 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-25m)
- support macbook JIS keyboard

* Thu Nov 22 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-24m)
- update squashfs-3.3
- CONFIG_X86_CPUFREQ_NFORCE2 was "not set"

* Tue Nov 20 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.23-23m)
- update x86_64*.config (to enable build on x86_64)

* Tue Nov 20 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-22m)
- update 2.6.23.8

* Thu Nov 15 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-21m)
- update thinkpad-acpi-0.18-20071112
- update unionfs-2.1.9

* Tue Nov 13 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-20m)
- update tuxonice-3.0-rc2-for-2.6.23.1
- update madwifi-ng-r2845-20071113

* Mon Nov 11 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-19m)
- remake kernel-2.6.23-x86_64-*.config
-- i686 was made a base. 

* Wed Nov  7 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-18m)
- update iwlwifi-1.1.21
- update unionfs-2.1.8
- import many patch from Fedora

* Tue Oct 30 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-17m)
- update reiser4 patch
- add thinkpad-acpi-0.18

* Sun Oct 28 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.23-16m)
- update x86_64*.config (to enable build on x86_64)

* Sat Oct 28 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-15m)
- add %%preun
- update nilfs-2.0.0-testing-6
- update ivtv-1.0.3
- update unionfs-2.1.7
- import many Fedora patch
-- no change x86_64 config.....

* Fri Oct 26 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.23-14m)
- update iwlwifi to 1.1.19

* Sat Oct 20 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.23-13m)
- Prereq: /usr/bin/find -> findutils

* Fri Oct 19 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.23-12m)
- [SECURITY] update madwifi to 0.9.3.3
- This release fixes a security issue (CVE-2007-5448) and compilation for the recently released kernel 2.6.23.

* Thu Oct 18 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.23-11m)
- specopt-nize
- delete unused "usagi_ipv6 ............ %{usagi_ipv6}"
- adapt print_specopt()
- update linux-2.6-debug-extra-warnings.patch
- update linux-2.6-debug-slub-debug.patch

* Thu Oct 18 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.23-10m)
- update alsa-driver-1.0.15rc3-SE200PCI.patch

* Sun Oct 14 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-9m)
- update 2.6.23.1
- update nilfs-2.0.0-testing-4

* Fri Oct 12 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.23-8m)
- set CONFIG_HIBERNATION=y and CONFIG_PM_STD_PARTITION=""
  on i686*.config and x86_64*.config

* Thu Oct 11 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-7m)
- enable PAE/debug kernel

* Thu Oct 11 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-6m)
- enable squashfs
- cleanup spec

* Thu Oct 11 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-5m)
- update madwifi-stable madwifi-0.9.3.2
- update unionfs-2.1.6

* Thu Oct 11 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-4m)
- update madwifi-ng-r2732-20071009

* Thu Oct 11 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-3m)
- add iwlwifi-1.0.17

* Wed Oct 10 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.23-2m)
- start 2.6.23-stable
- add btrfs-0.8
- enable nilfs-2.0.0-testing3
- enable ivtv-1.0.2
- enable reiser4fs

* Wed Oct 10 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.23-1m)
- update Source0: linux-2.6.23.tar.bz2
- update patch:
  Patch10: linux-2.6.23-utrace.patch
- remove patches:
  Patch690: linux-2.6-at76.patch
  Patch680: linux-2.6-wireless.patch
  Patch681: linux-2.6-wireless-pending.patch
  Patch682: linux-2.6-iwlwifi-fixes.patch
  Patch691: linux-2.6-ath5k.patch
  Patch692: linux-2.6-zd1211rw-mac80211.patch
  Patch693: linux-2.6-mac80211-extras.patch
  Patch901: sched-cfs-v2.6.23-rc8-v22.patch

* Sun Oct  6 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.23-0.9.3m)
- add patches:
  Patch662: linux-2.6-libata-pata-dma-disable-option.patch
  Patch680: linux-2.6-wireless.patch
  Patch681: linux-2.6-wireless-pending.patch
  Patch682: linux-2.6-iwlwifi-fixes.patch
  Patch690: linux-2.6-at76.patch
  Patch691: linux-2.6-ath5k.patch
  Patch692: linux-2.6-zd1211rw-mac80211.patch
  Patch693: linux-2.6-mac80211-extras.patch
- update x86_64 config files    

* Fri Oct  5 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.23-0.9.2m)
- enhance Envy24HT alsa-dirver for ONKYO SE-200PCI and SE-90PCI, thanks JW
- http://mailman.alsa-project.org/pipermail/alsa-devel/2007-October/003468.html
- http://www.d4.dion.ne.jp/~sh_okada/

* Thu Oct  4 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.23-0.9.1m)
- upate Patch0: patch-2.6.23-rc9
- modify Patch901: sched-cfs-v2.6.23-rc8-v22.patch

* Thu Sep 27 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.23-0.8.1m)
- update Patch0: patch-2.6.23-rc8
- update Patch10: linux-2.6.23-rc8-utrace.patch
- update Patch780: linux-2.6-highres-timers.patch
- update Patch901: sched-cfs-v2.6.23-rc8-v22.patch
- update Patch1460: unionfs-2.1.5_for_2.6.23-rc8.diff.gz
- delete Patch1506: linux-2.6-xfs-fix-filestreams-free-func-cast.patch

* Fri Sep 21 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.23-0.7.1m)
- update Patch0: patch-2.6.23-rc7
- update Patch10: linux-2.6.23-rc7-utrace.patch
- update Patch1460: unionfs-2.1.4_for_2.6.23-rc7.diff.gz
- delete Patch1501: linux-2.6-xfs-filestreams-on-demand-MRU-reaping.patch

* Wed Sep 12 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.23-0.6.2m)
- update spec to take git patches
- Patch2: patch-2.6.23-rc6-git1 (can build but not applied)
- Patch1460: unionfs-2.1.3_for_2.6.23-rc6.diff.gz

* Tue Sep 11 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.23-0.6.1m)
- Patch0: patch-2.6.23-rc6
- update Patch10: linux-2.6.23-rc6-utrace.patch
- update Patch150: linux-2.6-build-nonintconfig.patch
- delete included Patch900: linux-2.6.23-rc5-tcpinput.patch
- delete included Patch1500: linux-2.6-xfs-sane-filestreams-object-timeout.patch
- delete included Patch1502: linux-2.6-xfs-quota-hashtable-allocation-fix.patch

* Thu Sep  6 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.23-0.5.4m)
- update Patch10: linux-2.6.23-rc5-utrace.patch 

* Tue Sep  4 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.23-0.5.3m)
- renumber duplicated Patch1500 to Patch2500
- add CONFIG_E1000E=m in ix86 config files

* Tue Sep  4 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.23-0.5.2m)
- patches from fc devel
- Patch900: linux-2.6.23-rc5-tcpinput.patch

* Mon Sep  3 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.23-0.5.1m)
- Patch0: patch-2.6.23-rc5
- update Patch10: linux-2.6.23-rc5-utrace.patch
- use macro for Patch10

* Thu Aug 30 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.23-0.4.1m)
- Patch0: patch-2.6.23-rc4

* Tue Aug 28 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.23-0.3.2m)
- update x86_64 config file

* Wed Aug 15 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.23-0.3.1m)
- Patch0: patch-2.6.23-rc3
- various patches from fc8 devel
- build x86_64 arch only

* Sun Jul 15 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-3m)
- Patch901: sched-cfs-v2.6.22.1-v19.mo.patch
- Patch1460: linux-2.6.22.1-u2.diff.gz

* Wed Jul 11 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-2m)
- Patch1: patch-2.6.22.1.bz2 (CVE-2007-2876)

* Mon Jul  9 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-1m)
- Source0: linux-2.6.22
- Patch10: linux-2.6-utrace.patch
- Patch901: sched-cfs-v2.6.22-v19.patch

* Sat Jul  7 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-0.7.4m)
- Patch901: sched-cfs-v2.6.22-rc7-v19.patch
- edit spec to remove providing alsa driver
- Patch680: git-wireless-dev.mo.patch 
- revive CONFIG_ACPI_ASUS=m

* Sat Jul  7 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-0.7.3m)
- experiment Mo4 standard config settings

* Wed Jul  4 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-0.7.2m)
- Patch1460: linux-2.6.22-rc7-u1.diff

* Mon Jul  2 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-0.7.1m.mo4)
- Patch0: patch-2.6.22-rc7
- Patch901: sched-cfs-v2.6.22-rc7-v18.patch
- Patch10: linux-2.6.22-rc7-utrace.mo.patch

* Sat Jun 30 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-0.6.2m.mo4)
- enabled debuginfo
  not to build debuginfo package, set _enable_debug_packages to 0 

* Mon Jun 25 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-0.6.1m)
- Patch0: patch-2.6.22-rc6
- Patch901: sched-cfs-v2.6.22-rc6-v18.patch
- Patch10: linux-2.6.22-rc6-utrace.mo.patch

* Sun Jun 24 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-0.5.5m)
- remove Patch902: linux-2.6-use-pageallocator.patch

* Sat Jun 23 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-0.5.4m)
- Patch901: sched-cfs-v2.6.22-rc5-v18.mo.patch
- Patch10: linux-2.6.22-current-utrace.mo.patch

* Fri Jun 22 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-0.5.3m)
- Patch900: linux-2.6-sched-cfs.patch
- Patch901: sched-cfs-v2.6.22-rc5-v17.patch 
- Patch95: linux-2.6-kvm-suspend.patch

* Wed Jun 20 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-0.5.2m)
- Patch1460: linux-2.6.22-rc5-u1.diff.gz -- unionfs

* Sun Jun 17 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-0.5.1m)
- Patch0: patch-2.6.22-rc5
- Patch10: linux-2.6.22-rc5-utrace.patch
- update spec fixing double entry

* Sat Jun 16 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-0.4.4m)
- implemented ApplyPatch following fc sample
- SLUB enabled

* Sun Jun 10 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-0.4.3m)
- copied patches from FC devel

* Sat Jun  9 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-0.4.2m)
- Patch800: linux-2.6-build-nonintconfig.patch

* Fri Jun  8 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-0.4.1m)
- Patch0: patch-2.6.22-rc4
- Patch1460: linux-2.6.22-rc4-u1 

* Sat Jun  2 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-0.3.2m)
- patches from FC devel

* Sat May 26 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-0.3.1m)
- Patch0: patch-2.6.22-rc3

* Fri May 25 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.22-0.2.1m)
- Patch0: patch-2.6.22-rc2
- Patch1462: linux-2.6.22-squashfs-soontoremove.patch
- unionfs temporarily removed
- removed various patches

* Fri May 25 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-15m)
- update 2.6.21.3

* Wed May 23 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-14m)
- import any patch from Fedora

* Wed May 23 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-13m)
- update backport cpufreq patches 
-- Patch3: cpufreq-backport1.patch
-- Patch4: cpufreq-backport2.patch
- update backport XFS patche
-- Patch1480: xfs-backport.patch

* Tue May 22 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-12m)
- backport XFS patches 
-- Patch1480: xfs-propogate-return-codes-from-flush-routines.patch
-- Patch1481: xfs-fix-race-condition-xfs_write.patch
-- Patch1482: xfs-null-file-problem.patch
-- Patch1483: xfs-fix-race-condition-xfs_write-dmapi.patch
-- Patch1484: xfs-add-lockdep-support.patch

* Mon May 21 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-11m)
- fix ReiserFS warning 
-- linux-2.6-reiserfs-suppress-lockdep.patch
-- reiserfs-possible-null-pointer-dereference.patch
- import any patch from fc 
- cleanup spec

* Sat May 19 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-10m)
- import any patch from fc 

%changelog
* Wed May 16 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-9m)
- update reiser4-patch
- update ipw3945-1.2.0 patch
- update ALSA-1.0.14-rc4
- update swsuspend-2.2.9.16

* Tue May 15 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.21-8m)
- enable Momonga boot logo on
  i586, i686-xen, i686, ppc64-kdump, ppc64, x86_64-kdump, x86_64-xen and x86_64
  (set "# CONFIG_LOGO_LINUX_CLUT224 is not set")

* Tue May 15 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-7m)
- import any patch from Fedora
- update madwifi-hal-0.9.30.13

* Fri May 11 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-6m)
- import any patch from Fedora
- cleanup spec 

* Mon May  7 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-5m)
- Patch11: linux-2.6.21-utrace.patch
- modified spec at %post: *FC* -> *mo* in link name setting for devel packages 
- do not appy kdb patches --- build_kdb set to 0

* Sun May  6 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-4m)
- update KDB-4.4 
- update unionfs-2.6.21-u2
- update software-suspend-2.2.9.13-2.6.21-rc7
- update reiser4(2.6.21-mm1)
- initial support ps3
-- boot has not been done yet

* Mon Apr 30 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-3m)
- update nouveau-drm.patch
- support kvm-21

* Sun Apr 29 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-2m)
- update 2.6.21.1
- CONFIG_SECURITY_CAPABILITIES=y 
-- capability.ko was need by named

* Thu Apr 26 2007 Shigeru Yamazaki <muradaikan@momonnga-linux.org>
- (2.6.21-1m)
- update source

* Wed Apr 25 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-0.7.2m)
- update reiser4 patch(2.6.21-rc7-mm1) 

* Wed Apr 18 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-0.7.1m)
- update 2.6.21-RC7
- update reiser4 patch(2.6.21-rc6-mm1) 

* Mon Apr  9 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.21-0.6.3m)
- -CONFIG_SECURITY_CAPABILITIES=y +CONFIG_SECURITY_CAPABILITIES=m
  for prepare about rlocate

* Mon Apr  9 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.21-0.6.2m)
- enable CONFIG_IKCONFIG=y and CONFIG_IKCONFIG_PROC=y for /proc/config.gz

* Fri Apr  6 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.6.1m)
- Patch0: patch-2.6.21-rc6
- Patch 11: linux-2.6.21-rc6-utrace.patch
- update Patch12: nouveau-drm.patch

* Thu Apr  5 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.5.5m)
- Source2400: madwifi-hal-0.9.30.10-current.tar.bz2 (r2249-20070329)
- Patch1460: linux-2.6.21-rc5-u1 for unionfs

* Fri Mar 30 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.5.4m)
- Source2400: madwifi-0.9.3.tar.bz2

* Wed Mar 28 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.5.3m)
- Patch11: linux-2.6.21-rc5-utrace.patch

* Tue Mar 27 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.5.2m)
- update config files

* Mon Mar 26 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.5.1m)
- Patch0: patch-2.6.21-rc5

* Sat Mar 24 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.4.4m)
- Patch1460: linux-2.6.21-rc4-u2.diff.gz
- Source2400: madwifi-ng-r2210-20070324

* Thu Mar 22 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.4.3m)
- Patch1460: linux-2.6.21-rc4-u1.diff.gz 

* Sun Mar 18 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.4.2m)
- use straight copies of config files from fc7 development and 
  slightly modify to suit Momonga Linux
- modified spec to accommodate the changes in spec files

* Sat Mar 18 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-0.4.1m)
- update 2.6.21-rc4
-- add config CONFIG_ACPI_IBM_BAY=y

* Sun Mar 11 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.3.6m)
- revise kernel-2.6.21-x86_64.config for IPTABLES

* Sat Mar 10 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.3.5m)
- Patch1460: linux-2.6.21-rc3-u1.diff.gz

* Thu Mar  9 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.3.4m)
- revive Patch1400: squashfs3.2-patch.bz2
  squashfs3.2-r2.tar.gz doesn't patch the source ... orz

* Thu Mar  8 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.3.3m)
- support Reiser4 FileSystem

* Thu Mar  8 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.3.2m)
- revive forgotten squashfs in config files

* Wed Mar  7 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.3.1m)
- Patch0: patch-2.6.21-rc3
- enabled all PATA drivers as modules
- enabled unionfs

* Thu Mar  1 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.2.1m)
- Patch0: patch-2.6.21-rc2

* Wed Feb 21 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.1.1m)
- Patch0: patch-2.6.21-rc1
- Patch11: linux-2.6.21-rc1-utrace.patch
- removed reiser4 patches

* Tue Feb 20 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.20-3m)
- Patch1: patch-2.6.20.1 (CVE-2007-0772)

* Mon Feb 12 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.20-2m)
- Patch30: Suspend2 2.2.9.7
- Source2400: madwifi-ng-r2100-20070210

* Mon Feb  5 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.20-1m)
- Source0; linux-2.6.20

* Thu Feb  1 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.20-0.7.1m)
- Patch0: patch-2.6.20-rc7

* Thu Jan 25 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.20-0.6.1m)
- Patch0: patch-2.6.20-rc6

* Sat Jan 13 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.20-0.5.1m)
- Patch0: patch-2.6.20-rc5
- update Patch1740

* Mon Jan 08 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.20-0.4.1m)
- Patch0: patch-2.6.20-rc4

* Tue Jan 02 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.20-0.3.1m)
- Patch0: patch-2.6.20-rc3
- updated Patch11: linux-2.6-utrace.patch

* Mon Dec 25 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.20-0.2.1m)
- Patch0: patch-2.6.20-rc2
- updated Patch11: linux-2.6-utrace.patch 

* Sat Dec 23 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.20-0.1.7m)
- update config files for x86_64

* Wed Dec 20 2006 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.20-0.1.6m)
- modify i586 and i686 configs based on 2.6.19-1.2885.fc7
- ATA/ATAPI/MFM/RLL support is still enabled, take care

* Wed Dec 20 2006 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.20-0.1.5m)
- Support Reiser4
-- patch 1410-1436

* Wed Dec 20 2006 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.20-0.1.4m)
- modify following sections of i586 and i686 configs
  IPVS application helper
  Core Netfilter Configuration
  IP: Netfilter Configuration
  Hardware Monitoring support
  Character devices
  Miscellaneous USB options
  USB Host Controller Drivers

* Wed Dec 20 2006 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.20-0.1.3m)
- modify i586 and i686 configs to enable booting from SATA disks

* Wed Dec 20 2006 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.20-0.1.2m)
- change i686 configs for build on i686 archs

* Sun Dec 17 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.20-0.1.1m)
- Patch0: patch-2.6.20-rc1
- patches from fc7 kernel package
- build on x86_64 arch only and others will not build yet

* Wed Dec 13 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.19-3m)
- Patch1: patch-2.6.19.1

* Sun Dec 10 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.19-2m)
- update spec and provide kernel-headers package
- Patch2: patch-2.6.19-git18

* Thu Nov 30 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.19-1m)
- Source0; linux-2.6.19

* Mon Nov 20 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.19-0.6.3m)
- modify config file
  # CONFIG_PREEMPT_NONE is not set
  CONFIG_PREEMPT_VOLUNTARY=y
  # CONFIG_CRASH_DUMP is not set
  CONFIG_CC_STACKPROTECTOR=y
  CONFIG_CC_STACKPROTECTOR_ALL=y
  CONFIG_HZ_250=y
  CONFIG_SSFDC=m 
  CONFIG_DLM=m
  CONFIG_CRYPTO_TWOFISH_X86_64=m
  
* Sat Nov 18 2006 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.19-0.6.2m)
- enable EXT4 FS in config files
  patch for config files is below
  -# CONFIG_EXT4DEV_FS is not set
  +CONFIG_EXT4DEV_FS=m
  +CONFIG_EXT4DEV_FS_XATTR=y
  +CONFIG_EXT4DEV_FS_POSIX_ACL=y
  +CONFIG_EXT4DEV_FS_SECURITY=y
  +CONFIG_JBD2=m
  +# CONFIG_JBD2_DEBUG is not set
  and only kernel-2.6.19-x86_64-xen.config is changed below
  -CONFIG_EXT4DEV_FS=y
  +CONFIG_EXT4DEV_FS=m
  -CONFIG_JBD2=y
  +CONFIG_JBD2=m  

* Sat Nov 18 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.19-0.6.1m)
- Patch0: patch-2.6.19-rc6

* Sat Nov 11 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.19-0.5.2m)
- enable nilfs-1.0.14

* Thu Nov 09 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.19-0.5.1m)
- Patch0: patch-2.6.19-rc5

* Wed Nov 08 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.19-0.4.2m)
- use smp config for i586 i686 and x86_64
- test build for x86_64 ONLY

* Tue Nov  7 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.19-0.4.1m)
- Patch0: patch-2.6.19-rc4

* Sat Oct 29 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-2m)
- Patch0: patch-2.6.19-rc3

* Fri Sep 22 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-1m)
- Source0: linux-2.6.18

* Sat Sep 16 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.7.2m)
- revised config files for x86_64

* Wed Sep 13 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.7.1m)
- Patch0: patch-2.6.18-rc7

* Wed Sep 6 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.6.2m)
- revised config files for x86_64
  enabled NUMA for smp
    CONFIG_NUMA=y
    CONFIG_K8_NUMA=y
    CONFIG_X86_64_ACPI_NUMA=y
    CONFIG_NUMA_EMU=y
    CONFIG_ACPI_NUMA=y

* Tue Sep 5 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.6.1m)
- Patch0: patch-2.6.18-rc6

* Tue Aug 29 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.4.4m)
- set NTFS_FS=m and NTFS_RW=y in config files 

* Tue Aug 22 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.4.3m)
- update ix86 config files

* Thu Aug 17 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.4.2m)
- revive some patches that were removed at 2.6.18-0.4.1m

* Sat Aug 12 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.4.1m)
- built without xen, reiser4, nilfs, ipw3945

* Mon Jul 31 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.2.4m)
- restructure packaging to follow trunk kernel

* Fri Jul 21 2006 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.18-0.2.3m)
- enable Reiser4 FS
- Patch1001: reiser4-for-2.6.17-1.patch.gz
- Patch1003: reiser4-vs-zoned-allocator.patch
- Patch1004: reiser4-get_sb_dev-fix.patch
- Patch1005: make-copy_from_user_inatomic-not-zero-the-tail-on-i386-vs-reiser4.patch
- Patch1010: reiser4-2.6.17-writeback_control.patch

* Wed Jul 19 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.2.2m)
- Patch530: linux-2.6.18-dbus.patch
- update ix86 config files

* Sun Jul 16 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.2.1m)
- Patch1: patch-2.6.18-rc2
- only x86_64 config files are updated
- xen and unionfs are disabled

* Sat Jul 08 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.1.1m)
- Patch1: patch-2.6.18-rc1

* Fri Jul 06 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-6m)
- Patch0: patch-2.6.17.4

* Wed Jul 05 2006 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.17-5m)
- patch : apply patch2202 -p1 ifarch %%i686 for unionfs build
- config: delete CONFIG_SCSI_ADVANSYS only i686
- config: add missing config only i686

* Fri Jun 30 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-4m)
- attempt to revive xen - not complete and still experimental
- tested on x86_64 arch only 
- patches copied from FC6

* Sat Jun 24 2006 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.17-3m)
- update squashfs3.0-patch.bz2

* Tue Jun 20 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-2m)
- Patch0: patch-2.6.17.1

* Mon Jun 19 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-1m)
- built with x86_64 spec only

* Wed Jun 15 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-0.6.2m)
- Source2500: unionfs-1.2
- unionfs source is merged into kernel source tree for building

* Wed Jun  7 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-0.6.1m)
- patch0: prepatch-2.6.17-rc6

* Sat May 27 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-0.5.1m)
- patch0: prepatch-2.6.17-rc5

* Thu May 11 2006 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.17-0.3.2m)
- add linux-2.6.16-snd_cs4281-alsa-1.0.11.patch
  https://bugtrack.alsa-project.org/alsa-bug/view.php?id=1976
- import alsa-driver-1.0.11.via82xx.diff.gz from Slackware
  https://bugtrack.alsa-project.org/alsa-bug/view.php?id=2067

* Sat Apr 29 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-0.3.1m)
- Prepatch: patch-2.6.17-rc3
- linux26-2.6.16-usagi-20060423
- madwifi ng-r1523-20060423
- Source3090: Suspend2-2.2.5-for-2.6.17-rc2 not applied 

* Fri Apr 21 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-0.2.1m)
- Prepatch: patch-2.6.17-rc2
- Source3090: Suspend2-2.2.4.1-for-2.6.17-rc1 patch temporarily not applied
- edit spec to include Module.symvers
- remove Source3091: 582-refrigerator.momo3
- remove Source3092: 201-ati-agp.momo2
- remove Source3093: 209-get-module-list.momo1
- remove Source3094: 210-workthreads.momo1

* Fri Apr  7 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-0.1.4m)
- Patch50: linux26-2.6.16-usagi-20060406.patch.gz

* Thu Apr  6 2006 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.17-0.1.3m)
- update {i686,i686-smp,i586,i586-smp}.config for iptables

* Wed Apr  5 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-0.1.2m)
- update x86_64 config files for iptables

* Wed Apr  5 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-0.1.1m)
- Prepatch: patch-2.6.17-rc1
- add CONFIG_SCSI_ADVANSYS=m to x86_64 and ppc config files
- add CONFIG_NETFILTER_XTABLES=m and related settings to i586/i686 config files

* Tue Apr  4 2006 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.16-5m.dev)
- import advansys patches from Fedora Core devel
 - linux-2.6-scsi-advansys-enabler.patch
 - linux-2.6-scsi-advansys-pcitable.patch
- add CONFIG_SCSI_ADVANSYS=m to {i686,i686-smp,i586,i586-smp}.config

* Sun Apr  2 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-4m.dev)
- Source3090: suspend2-2.2.4-for-2.6.16.tar.bz2

* Fri Mar 31 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-3m)
- Patch1001: reiser4-for-2.6.16-1.patch.gz 

* Sun Mar 26 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-2m)
- Source: 2.6.16.1

* Sun Mar 26 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-1m)
- unionfs is not included in this version
- config files available only for x86_64 architecture

* Tue Mar 14 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-0.6.1m)
- Prepatch: patch-2.6.16-rc6

* Wed Mar 01 2006 Masanobu Sato <satoshiga@momonga-linux.org>
- (2.6.16-0.5.2m)
- revised kernel.spec

* Tue Feb 28 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-0.5.1m)
- Prepatch: patch-2.6.16-rc5
- Source2400: madwifi-ng-r1457-20060228

* Thu Feb 23 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-0.4.2m)
- experimenting the Completely Fair Queuing (CFQ) scheduler as 
  the default algorthim:
  CONFIG_DEFAULT_AS=y             -> CONFIG_DEFAULT_AS is not set 
  CONFIG_DEFAULT_CFQ is not set   -> CONFIG_DEFAULT_CFQ=y
- edit config files:
  CONFIG_HZ=250                   -> CONFIG_HZ=1000
  CONFIG_HZ_250=y                 -> CONFIG_HZ_250 is not set
  CONFIG_HZ_1000 is not set       -> CONFIG_HZ_1000=y
  CONFIG_PM_LEGACY is not set     -> CONFIG_PM_LEGACY=y
- Above work was inspired by ichro. Thank you. 
- Source2500: unionfs-1.1.3.tar.gz

* Sat Feb 18 2006  Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-0.4.1m)
- Prepatch: patch-2.6.16-rc4
- Source2500: unionfs-1.1.2.tar.gz
- Source2600: nilfs-1.0.6.tar.bz2
- Patch2200: unionfs-mkdir-unionfs112.patch
- remove Patch3008: linux-2.6.14-unionfs-ppc.patch

* Mon Feb 13 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-0.3.1m)
- Prepatch: patch-2.6.16-rc3

* Sun Feb 5 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-0.2.1m)
- Prepatch: patch-2.6.16-rc2
- experimenting NOT merging alsa-driver source

* Sat Feb 4 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-0.1.3m)
- edit spec and config files for SUSPEND2 (for build only)
  SUSPEND2 functionality is not tested

* Fri Jan 27 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-0.1.2m)
- Patch50: linux26-2.6.15-usagi-20060201.patch.gz
- Patch600: kernel-shut-the-gcc41warning.patch
  only for gcc4.1: set use_gcc41 1 to apply patch
- Source2600: nilfs-1.0.5.tar.bz2

* Thu Jan 19 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-0.1.1m)
- prepatch: patch-2.6.16-rc1
- Alsa Driver: alsa-1.0.11rc2
- Source2600: nilfs-1.0.4 and not NoSource
- Source3090: software-suspend-2.2-for-2.6.15.1
- Patch1001: reiser4-for-2.6.15-1
- remove Patch1401
- update configs for 2.6.16
  almost straight copies with some new alsa modules

* Tue Jan 17 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-5m)
- update kernel-2.6.15-x86_64-smp.config

* Thu Jan 12 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-4m)
- Patch50: linux26-2.6.15-usagi-20060111.patch.gz
- Source3090: software-suspend-2.2-rc16-for-2.6.15
- removed /lib/modules/$KernelVer/build/include/config/MARKER from packaging 

* Sat Jan 7 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-3m)
- Patch100: linux-2.6-gcc41.patch
- Patch2008: linux-2.6.14-sis5513.patch
- x86_64 is added in for building madwifi and unionfs

* Thu Jan 5 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-2m)
- kdb_kernel_ver 2.6.15
- Patch50: linux26-2.6.15-usagi-20060105.patch.gz

* Wed Jan 4 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-1m)
- Source0: linux-2.6.15

* Mon Jan 02 2006 mutecat <mutecat@momonga-linux.org>
- (2.6.15-0.7.7m)
- arrange ppc.

* Sat Dec 31 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-0.7.6m)
- use /sbin/modinfo instead of /sbin/modinfo.old -- copied from 2.6.14-13m spec by takahata

* Thu Dec 29 2005 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.15-0.7.5m)
- modify {i686, i686-smp, i586, i586-smp}.config for ALSA
- add kernel-2.6.15-rc1-fix-alsa-bad-page.patch
  http://lkml.org/lkml/2005/11/19/82

* Wed Dec 28 2005 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.15-0.7.4m)
- add CONFIG_PM_LEGACY=y to {i686, i686-smp, i586, i586-smp}.config

* Tue Dec 27 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-0.7.3m)
- Source3090: software-suspend-2.2-rc15-for-2.6.15-rc7
- Patch50: linux26-2.6.15-rc7-usagi-20051226.patch.gz
- Source2400: madwifi-ng-current.tar.gz
   IF building fails with "missing Makefile.cpu" comment out for madwifi-ng-current.tar.gz 
   and use madwifi-cvs-current.tar.bz2 instead -- error will occur when building 2.6.15-0.7.2m
   has been skipped

* Mon Dec 26 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-0.7.2m)
- edit spec to package Makefile.cpu

* Sun Dec 25 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-0.7.1m)
- prepatch: patch-2.6.15-rc7

* Fri Dec 23 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-0.6.2m)
- update config files --- new modules are "not set" and ppc and x86 may not build
- reiser4 patch not applied
- Source3090: software-suspend-2.2-rc14-for-2.6.15-rc5
- Patch50: linux26-2.6.15-rc6-usagi-20051222.patch.gz

* Tue Dec 20 2005 Shigeru Yamazaki <muradaikan@momonga-lilnux.org>
- (2.6.15-0.6.1m)
- prepatch: patch-2.6.15-rc6
- Alsa Driver: alsa-1.0.10

* Thu Dec 15 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-12m)
- Source: 2.6.14.4
- Source3090: software-suspend-2.2-rc14-for-2.6.14

* Sat Nov 26 2005 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.14-11m)
- changed config files
-  Source28: kernel-2.6.14-x86_64.config
-  Source29: kernel-2.6.14-x86_64-smp.config

* Sat Nov 26 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-10m)
- Source: 2.6.14.3
- Source3090: software-suspend-2.2-rc13-for-2.6.14

* Wed Nov 23 2005 mutecat <mutecat@momonga-linux.org>
- (2.6.14-9m)
- arrange ppc
- add linux-2.6.14-usbaudio-ppc.patch from linux-usb-devel with arrange
- add linux-2.6.14-tea575x-ppc.patch
- add linux-2.6.14-unionfs-ppc.patch

* Tue Nov 22 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-8m)
- Source3090: software-suspend-2.2-rc12-for-2.6.14
- Source2300: hostap-driver-0.4.7.tar.gz
- Source2400: madwifi-cvs-current.tar.gz
- Source2600: nilfs-1.0.3.tar.bz2
- Patch50: linux26-2.6.14-usagi-20051121.patch.gz

* Mon Nov 14 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-7m)
- add config files in attempt to compile additional packages
  Source26: kernel-2.6.14-ppc.config
  Source27: kernel-2.6.14-ppc-smp.config
  Source28: kernel-2.6.14-x86_64.config
  Source29: kernel-2.6.14-x86_64-smp.config
- changed config files for i686 and i586, and their smp

* Sat Nov 12 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-6m)
- Patch531: linux-2.6.14-dbus-smp.patch -- see if x86_64 can be built

* Sat Nov 12 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.14-5m)
- Source2600: nilfs-1.0.2.tar.bz2
- update Patch531 to linux-2.6.14-dbus-non-ix86.patch

* Sat Nov 12 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-4m)
- Source: 2.6.14.2
- Patch1001: reiser4-for-2.6.14-1.patch.gz
- Patch1002: reiser4-export-pagevec-funcs.patch
- CONFIG_REISER4_FS=m
- Source3090: software-suspend-2.2-rc9-for-2.6.14

* Sun Nov 6 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-3m)
- Patch530: linux-2.6.14-dbus.patch

* Tue Nov 1 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-2m)
- enable CODA_FS

* Fri Oct 28 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-1m)
- source 2.6.14

* Tue Oct 25 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-0.5.3m)
- Patches 70, 71, and 72: kdb_kernel_ver 2.6.14-rc5
- edit spec to accommodate HIMEM64G properly for related config files

* Mon Oct 24 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-0.5.2m)
- Patch50: linux26-2.6.14-rc5-usagi-20051024.patch.gz 
    attempt only and not applied
- Source2300: hostap-driver-0.4.5.tar.gz
- Source2500: unionfs-1.0.14
- Source2600: nilfs-1.0.1.tar.bz2

* Fri Oct 21 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-0.5.1m)
- prepatch 2.6.14-rc5

* Sat Oct 15 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.14-0.4.2m)
- update madwifi driver

* Wed Oct 12 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-0.4.1m)
- prepatch 2.6.14-rc4

* Sun Oct 9 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-0.3.1m)
- prepatch 2.6.14-rc3
- Source3090: software-suspend-2.2-rc8-for-2.6.14-rc3
   but NOT applied as it builds ext3.ko with unknown symbol

* Wed Sep 28 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.14-0.2.3m)
- use KSRC instead of KERNELPATH at nilfs (thanks to Dai san)
- change Patch1300 about function refrigerator part
- update unionfs to 20050927-1408

* Mon Sep 26 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.14-0.2.2m)
- add Source2600: http://www.osrg.net/nilfs/nilfs-1.0.0.tar.bz2
- change nilfs source file for conflicts with swsusp2(?)
- change nilfs Makefile < unionfs Makefile
- make Patch1300: nilfs-1.0.0.patch

* Fri Sep 23 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-0.2.1m)
- pretach 2.6.14-rc2
- build for only i586, i686, i586-smp, and i686-smp. Other configs not ready.

* Sat Sep 17 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-0.1.1m)
- prepatch 2.6.14-rc1
- source to build drivers for ipw2100 and ipw2200, and ieee80211 subsystem 
  are added in from prepatch-2.6.14-rc1
- remove the following for the above reason:
   Source 135, 136, 2300. Patch 1202, 1203, 1204, and 2003-7.
- Source2400: madwifi-cvs-snapshot-2005-09-14.tar.bz2
- Patch530: linux-2.6.14-dbus.patch
- build only i586, i686, i586-smp, and i686-smp. Other configs not ready.
- spec file has many lines that may no longer be needed.

* Sun Sep 11 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.13-3m)
- source 2.6.13.1
- Source3090: software-suspend-2.2-rc6-for-2.6.13
- Patch700: linux-2.6.13-mppe-mppc-1.3.patch.gz
- hostap-driver with Source2300: hostap-driver-0.4.4.tar.gz
- edit spec to have "srcversion" at some lines where "kversion" was specified

* Sun Sep 4 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.13-2m)
- ipw2100 and ipw2200 drivers - not sure if they work properly
- Patch1202: ipw2100-1.1.0-linux2613-momonga.patch - remove redefinition
- Patch1203: ipw2200-1.0.2-linux2613-momonga.patch
- Source136: ipw2200-1.0.2 - changed from 1.0.6 to sync with ipw2100-1.1.0
- SWSUSP2: apply software-suspend-2.2-rc5-for-2.6.13

* Wed Aug 31 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.13-1m)
- source 2.6.13
- SWSUSP2: apply software-suspend-2.2-rc4-for-2.6.13
- Temporarily skip applying Patch50: linux26-2.6.12-usagi-20050829.patch.gz
- Patch1200: linux-2.6.13-reiser4.patch (!!!module NOT in working order!!!)
   maybe needed until Reiserfs4 publishes a patch for 2.6.13
- Alsa driver 1.0.10rc1
- Skip building unionfs

* Sun Aug 28 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.12-7m)
- SWSUSP2: return to apply stable software-suspend-2.1.9.5-for-2.6.12
- Patch530: linux-2.6.12.5-dbus.patch

* Fri Aug 26 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.12-6m)
- source 2.6.12.5
- kernel config files for 2.6.12.5 are straight copies of 2.6.12.4 without alteration
- SWSUSP2: apply stable software-suspend-2.2-rc2-for-2.6.13-rc7
- Source2300 hostap-driver 0.4.1
- Source2400 madwifi-cvs-snapshot 2005-08-26
- Patch50 linux26-2.6.12-usagi-20050815.patch.gz
- kdb kernel-ver 2.6.12

* Sun Aug 22 2005 Dai OKUYAMA <dai@ouchi.nahi.to>
- (2.6.12-5m)
- update squashfs-2.2
- update unionfs-1.0.13
-  build fix unionfs

* Fri Aug 12 2005 Dai OKUYAMA <dai@ouchi.nahi.to>
- (2.6.12-4m)
- enable ppc.
-  add kernel-2.6.12.4-ppc.config, kernel-2.6.12.4-ppc-smp.config
-  cancel Patch3004
-  add Patch3005: fix for ``unknown symbol csum_ipv6_magic''

* Thu Aug 11 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.12-3m)
- Temporarily skip applying software-suspend-2.1.9.12-for-2.6.13-rc5
  to build package without halting and having to hit Enter key.

* Thu Aug 11 2005 Ryu SASAOKA <ryu@momonga-linux.org>
- (2.6.12-2m)
- enable x86_64. 
-  add kernel-2.6.12.4-x86_64.config, kernel-2.6.12.4-x86_64-smp.config
-  cancel patch100 (linux-2.6.10-x86_64-avoid-redefined-macros.patch)

* Tue Aug 9 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.12-1m)
- kernel source is linux-2.6.12.4
- tentatively builds only i586 i686 (not sure about their smp's)
- Patch50: linux26-2.6.12-usagi-20050807.patch.gz
- Patch500: linux-2.6.12-nonintconfig.patch
- Patch530: linux-2.6.12-dbus.patch
- Applying software-suspend-2.1.9.12-for-2.6.13-rc5 halts at
    230-refrigerator-to-try_to_freeze.patch and hit Enter to proceed (suman!)
- ALSAbasever 1.0.9b
- ieee1394 - use source in the kernel source
- IPW2*00 is not set in configs


* Sun Jul 17 2005 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.10-41m)
- remove any patch. because downgrade binutils
- Patch98: linux-2.6-seg-5.patch
- Patch99: linux-2.6-colinux-seg.patch

* Thu Jun 14 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-40m)
- add Patch100: linux-2.6.10-x86_64-avoid-redefined-macros.patch
- modified configs for x86_64.
- above fixes are just for x86_64, thus it would affect x86_64 only.

* Tue Jun  7 2005 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.10-39m)
- add binutils-2.90.16.0.3 assembler patch.

* Tue May 10 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-38.1m)
- add Patch4000: http://www.kernel.org/pub/linux/kernel/people/jgarzik/libata/old/2.6.10-bk9-libata-dev1.patch.bz2

* Fri May  6 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-38m)
- merge madwifi.
- merge unionfs.

* Thu Apr 28 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-37m)
- add Patch1100: squashfs2.1-patch.bz2
- add CONFIG_SQUASHFS=m into all kernel-2.6.10*.config

* Fri Apr 15 2005 Masahiro Takahata <takahata@momonga-linux.org>
- (2.6.10-36m)
- disable CONFIG_4KSTACKS
- disable buildxen temporarily

* Sun Apr 10 2005 Masahiro Takahata <takahata@momonga-linux.org>
- (2.6.10-35m)
- modify *.config with compatibile feature before 2.6.10-26m

* Thu Apr 07 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-34m)
- revised linux-2.6.10-xen.patch so that reiser4 potrion is built properly.
- CONFIG_AIC7XXX_PROBE_EISA_VL does not necessary.

* Thu Apr 07 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-33m)
- revised spec for x86_64 and ppc.

* Thu Apr 07 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-32m)
- xen.patch was extructed from xen-unstable-src.tgz.

* Mon Apr 04 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-31m)
- patchies including SWSUPS2, workqueue and coLinux are always applied.
- in the case of i686-smp, CONFIG_HIGHMEM64G is sellectable by specopt.

* Sat Apr 02 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-30m)
- add xen from kernel-2.6.10-1.1162_FC4/kernel-2.6.spec
- - add Patch450: linux-2.6.10-xen.patch
- - add Patch452: linux-2.6.9-xen-compile.patch
- - add Patch453: linux-2.6.9-xen-agpgart.patch
- - add Source37: kernel-2.6.10-i686-xen0.config
- - add Source38: kernel-2.6.10-i686-xenU.config
- rename config file number 37->30, 38->31
- add %%{SOURCE30} %%{SOURCE31} at 'mkdir configs' part
- update Patch452: linux-2.6.10-xen-compile.patch
- update Patch453: linux-2.6.10-xen-agpgart.patch

* Tue Mar 22 2005 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.10-29m)
- fixed PPP Server Denial of Service Vulnerability (CAN-2005-0384)

* Mon Mar 14 2005 Masahiro Takahata <takahata@momonga-linux.org>
- (2.6.10-28m)
- modify ppc config

* Mon Mar 14 2005 Dai OKUYAMA <dai@ouchi.nahi.to>
- (2.6.10-27m)
- fix ppc build. sorry... orz

* Tue Mar  8 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-26m)
- config files are fixed.

* Sun Mar  6 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-25m)
- use gcc_3_2 for coLinux.

* Sun Mar  6 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-24m)
- modified kernel-*.config. take care.

* Sat Mar  5 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-23m)
- simplified.

* Sat Mar  5 2005 mutecat <mutecat@momonga-linux.org>
- (2.6.10-22m)
- arrange ppc without patch 3005, 3006
- add FB driver
  CONFIG_FB_RADEON_OLD=y
  CONFIG_FB_RADEON=y
  CONFIG_FB_RADEON_I2C=y
  CONFIG_FB_ATY128=y

* Thu Mar  3 2005 Tsutomu Yasuda <tom@tom.homelinux.org>
- (2.6.10-21m)
  reiser4: update to 2.6.10-2

* Wed Mar  2 2005 Masahiro Takahata <takahata@momonga-linux.org>
- (2.6.10-20m)
- add CONFIG_TMPFS_XATTR=y CONFIG_TMPFS_SECURITY=y
- for ppc CONFIG_SECURITY_SELINUX_BOOTPARAM_VALUE=1

* Thu Feb 24 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-19m)
- CONFIG_PNPACPI is turned off.
- revised colinux-0.6.2-2.6.10.patch.
- %%{buildco} is always turned off other than %%{ix86}.

* Sat Feb 20 2005 minakami <minakami@momonga-linux.org>
- (2.6.10-18m)
- coLinux 0.6.2 support
- add new Source40: config-i586-co
- add new Source41: config-i686-co
- add new Source42: config-p4-co
- add new Source43: config-cm-co
- add new Source44: config-k7-co
- add new Source45: config-k8-co
- add new Source46: config-co-generic
- add new Patch93: colinux-0.6.2-2.6.10.patch
- add new Patch94: colinux-0.6.2-2.6.10-momonga.patch

* Sat Feb 19 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-17m)
- CONFIG_USB_HID, CONFIG_USB_KBD and CONFIG_USB_MOUSE is turned on.

* Wed Feb 16 2005 Dai OKUYAMA <dai@ouchi.nahi.to>
- (2.6.10-16m)
- add MEGARAID driver
  CONFIG_MEGARAID_NEWGEN=y
  CONFIG_MEGARAID_MM=m
  CONFIG_MEGARAID_MAILBOX=m
- add ppc patch from FC-devel.
- ppc-config renew.
  FIXME: ip6t_REJECT.ko ip6_conntrack.ko ip6_conntrack_ftp.ko unresolve symbols.

* Tue Jan 18 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-15m)
- rebuild on x86_64.

* Mon Jan 17 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-14m)
- add Patch700: http://www.polbox.com/h/hs001/linux-2.6.10-mppe-mppc-1.2.patch.gz
- set CONFIG_PPP_MPPE_MPPC=m in config-generic

* Fri Jan 14 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-13m)
- update to alsa-1.0.8
- add rm -f %%{swsusp2name}/950-alsa-fixes-already-in-bk

* Sat Jan 08 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-12m)
- add Patch580: 2.6.10-mm1-brk-locked.patch 
  from http://marc.theaimsgroup.com/?l=linux-kernel&m=110512844202355
  (VTS:00059)

* Fri Jan 07 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-11m)
- add new Patch1002: reiser4-export-find_get_pages_tag.patch

* Fri Jan 07 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-10m)
- update reiser4 patch
- delete Patch1002: reiser4-dont-use-shrink_dcache_anon.patch
- add 'chmod 644 drivers/scsi/a100u2w.c'
  for cp (prepare for madwifi and etc drivers)

* Thu Dec 30 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-9m)
- update usagi patch

* Tue Dec 28 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-8m)
- update madwifi driver (import from kernel24.spec)
- add 'CONFIG_ATHEROS=m', 'CONFIG_ATHEROS_HAL=m', 'CONFIG_ATHEROS_RATE=m'
  and 'CONFIG_NET80211=m' into config-generic
- set '# CONFIG_ATHEROS_HAL is not set', '# CONFIG_ATHEROS_RATE is not set' into config-generic
  reason:
  $ /sbin/modinfo.old -l /var/tmp/kernel-2.6.10-root/lib/modules/2.6.10-8m/kernel/drivers/net/wireless/_ath_hal/ath_hal.ko
  -> "Proprietary"
- comment out all making madwifi drivers part:
  because if we include madwifi drivers, kernel packages shall be Nonfree

* Tue Dec 28 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-7m)
- fix Source0 URI
- add 'CONFIG_PCCARD=m' and '# CONFIG_PCMCIA_OBSOLETE is not set' 
  into config-generic (thanks to tom san)
- add 'CONFIG_PCCARD=m', '# CONFIG_PCMCIA_OBSOLETE is not set', 
  'CONFIG_CARDBUS=y', 'CONFIG_I82365=m', and 'CONFIG_PCMCIA_PROBE=y'
  into config-ppc and config-ppc-smp
- why config-ppc and config-ppc-smp is same file?

* Tue Dec 28 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-6m)
- roll back software-suspend patch to 2.1.5.10-for-2.6.10-rc3
  cause 2.6.10-5m (software-suspend patch to 2.1.5.10-for-2.6.10)
  can not work hibernate my machine in progress 'Thawing other processors',
  but 2.6.10-4m (software-suspend patch to 2.1.5.10-for-2.6.10-rc3) can hibernate
- add Patch3092: 201-ati-agp.momo2
  from 2.1.5.10-for-2.6.10 one and fix below
  http://lists.berlios.de/pipermail/softwaresuspend-devel/2004-December/001382.html
- add Source3093: 209-get-module-list.momo1 from 2.1.5.10-for-2.6.10 one
- add Source3094: 210-workthreads.momo1 from 2.1.5.10-for-2.6.10 one
- ok, I can hibernate by 2.6.10-6m
- set '# CONFIG_LOGO_LINUX_CLUT224 is not set' in config-generic
  for enable Momonga boot logo (thanks to nakai san)

* Mon Dec 27 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-5m)
- update software-suspend patch to 2.1.5.10-for-2.6.10
- delete Source3094: 201-ati-agp.momo1 (included to swsusp2)
- delete Patch1200: linux-2.6.10-cx88-video-fake-arg.patch (included to swsusp2)
- rm kdb patches from software-suspend (momomai #100)

* Sun Dec 26 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-4m)
- update kdb patch to 2.6.10, but not tested (default disable)
- info: patch92 was used by prepare for dbus patch
- add Patch1002: reiser4-dont-use-shrink_dcache_anon.patch from 2.6.10-rc3-mm1
  for delete WARNING: /lib/modules/2.6.10-3m/kernel/fs/reiser4/reiser4.ko \
  needs unknown symbol shrink_dcache_anon
- update ipw2100 driver to 1.0.2
- update ipw2200 driver to 0.19
- update Patch2004: ipw2100-1.0.2-create_workqueue.patch
- update Patch2005: ipw2200-0.19-create_workqueue.patch
- info:
  %%{buildup} || %%{copper} || %%{pen4} || %%{amdk7} || %%{amdk8}
  was used buildup+buildsmp(default) and buildup only

* Sun Dec 26 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-3m)
- Patch2004 and Patch2005 apply ifarch *smp only

* Sun Dec 26 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-2m)
- update to software-suspend-2.1.5.10-for-2.6.10-rc3.tar.bz2
  cause 2.6.10-1m do not work swsusp2 my machine,
  stop in progress 'Doing atomic copy...'
- TODO: update Patch92: linux-2.6.9-swsusp-smp2.patch

* Sat Dec 25 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-1m)
- update to 2.6.10
  http://www.uwsg.indiana.edu/hypermail/linux/kernel/0412.3/0072.html
- update Source3091: 582-refrigerator.momo2
- update againt Source3091: 582-refrigerator.momo3
- add Source3092: 209-get-module-list.momo01
- update usagi patch and fix by hand
- update Patch500: linux-2.6.10-nonintconfig.patch
- update Patch530: linux-2.6.10-dbus.patch
- delete included Patch540: linux-2.6.6-online-resize.patch
- delete included Patch580: elf-loader-setuid-mo
- delete included Patch581: fix-aout-leak
- delete included Patch582: buffer-overrun-in-arch-x86_64-sys_ia32csys32_ni_syscall-sys32_vm86_warning.patch
- delete included Patch583: 2.6.10-rc3-decnet.patch
- delete included Patch584: gnupatch@41bf39b1RGfvOMInGewwDyzfcuL2OQ
- delete included Patch585: gnupatch@41b768d1ySHbfa7cUWDle8NjDT_02A
- delete included Patch2000:
  2.6.9-rc1/2.6.9-rc1-mm3/broken-out/scsi-qla2xxx-fix-inline-compile-errors.patch
- delete included Patch2010: security-fix-smbfs-2.6.9-ac3.patch
- add '# CONFIG_MODULE_SRCVERSION_ALL is not set' into config-generic
- add '# CONFIG_MEFFICEON is not set' into config-x86-generic
- add Source3093: 100-kdb-v4.4-2.6.9-rc2-common-1.momo1
  for s/TASK_ZOMBIE/EXIT_ZOMBIE/g , s/TASK_DEAD/EXIT_DEAD/g.
- add Source3094: 201-ati-agp.momo1
- add new Patch1200: linux-2.6.10-cx88-video-fake-arg.patch

* Wed Dec 22 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-0.3.1m)
- update to 2.6.10-rc3
- update swsusp2 patch
- update usagi patch
- update alsa patch

* Sun Dec 19 2004 mutecat <mutecat@momonga-linux.org>
- (2.6.9-22m)
- kossori

* Sat Dec 17 2004 mutecat <mutecat@momonga-linux.org>
- (2.6.9-21m)
- arrange ppc
- add Patch3000: linux-2.6.9-ppc.patch
- add Patch3001: linux-2.6.9-ppc-forc.patch
- add ppc config files

* Thu Dec 16 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-20m)
- add Patch585: gnupatch@41b768d1ySHbfa7cUWDle8NjDT_02A

* Thu Dec 16 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-19m)
- add Patch584: gnupatch@41bf39b1RGfvOMInGewwDyzfcuL2OQ

* Tue Dec 14 2004 Tsutomu Yasuda <tom@tom.homelinux.org>
- (2.6.9-18m)
  update hostap-driver 0.3.0
  update ieee1394 rev 1240
  update ipw2200 0.17
  update reiser4 3
  update software-suspend 2.1.5.7

* Mon Dec 13 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-17m)
- add Patch583: 2.6.10-rc3-decnet.patch

* Mon Dec 13 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-16m)
- add Patch582: buffer-overrun-in-arch-x86_64-sys_ia32csys32_ni_syscall-sys32_vm86_warning.patch

* Sun Dec 12 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-15m)
- add i686 to basearch

* Sun Dec 12 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-14m)
- add Patch581: fix-aout-leak

* Sun Dec 12 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-13m)
- add Patch580: elf-loader-setuid-mo

* Sat Dec 11 2004 Masayuki SANO <nosanosa@momonga-linux.org>
- (2.6.9-12m)
- CONFIG_DRM_I915=m in config-generic
- BuildPreReq: module-init-tools

* Tue Nov 30 2004 Tsutomu Yasuda <tom@tom.homelinux.org>
- (2.6.9-11m)
  support reiser4: patch 1001
  update ipw2100 1.0.1
  update ipw2200 0.15
  update ieee1394 rev 1234

* Sun Nov 28 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-10m)
- add Patch2010: security-fix-smbfs-2.6.9-ac3.patch from 2.6.9-ac3

* Thu Nov  4 2004 Shotaro Kamio <skamio@momonga-linux.org>
- (2.6.9-9m)
- add patch570 for compilation of NVIDIA driver

* Tue Nov 02 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-8m)
- delete dup obsoletes
- update usagi patch

* Thu Oct 28 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-7m)
- delete i2c

* Wed Oct 27 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-6m)
- re-add Patch91: linux-2.6.9-swsusp-smp.patch
  re-add Patch2004: ipw2100-0.56-create_workqueue.patch
  re-add Patch2005: ipw2200-0.12-create_workqueue.patch
  for fix build miss about up+smp (default)

* Sun Oct 24 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-5m)
- delete Patch91: linux-2.6.9-swsusp-smp.patch
- add apply swsusp2 patch %%{copper} %%{pen4} %%{amdk7} %%{amdk8}

* Sat Oct 23 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-4m)
- cancel Patch2004 and Patch2005

* Sat Oct 23 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-3m)
- add Patch92: linux-2.6.9-swsusp-smp2.patch
- use %%if %%{buildup} at patch2004 and patch2005 for %%{buildsmp}

* Sat Oct 23 2004 Kazuhiro Yoshida <moriq@moriq.com>
- (2.6.9-2m)
- update swsusp2 (Source3090)
- update Patch530: linux-2.6.9-dbus.patch
- add Patch91: linux-2.6.9-swsusp-smp.patch
- add Patch2004: ipw2100-0.56-create_workqueue.patch
- add Patch2005: ipw2200-0.12-create_workqueue.patch

* Thu Oct 21 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.9-1m)
- version up to 2.6.9
- update Source135 to ipw2100-0.56.tgz
- update Source136 to ipw2200-0.12.tgz
- update Patch530: linux-2.6.9-dbus.patch

* Fri Oct 15 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-0.4.4m)
- move out %%global usagi_ipv6 1 from specopt
  in specopt usagi_ipv6 shall set always 0, why?
- update usagi patch to 2.6.9-rc4-20041013
- add print_specopt() from kernel24.spec

* Fri Oct 15 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-0.4.3m)
- change specopt intel CPUs kernel default 0,
  specific intel CPUs kernel will not build, build up and smp kernel only
- change apply swsusp2 patches (Source3090 and Patch90) buildup only
- delete SWSUSP2 setting from config-generic
- add SWSUSP2 setting from config-i586 and config-i686

* Fri Oct 15 2004 Shingo Akagaki <dora@kitty.dnsalias.org>
- (2.6.9-0.4.2m)
- update and enable ipw2100 driver.
- add ipw2200 driver.

* Mon Oct 11 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-0.4.1m)
- update to 2.6.9-rc4

* Mon Oct 11 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-0.3.4m)
- add Patch2000: scsi-qla2xxx-fix-inline-compile-errors.patch
- add Patch2001: linux-2.6.9-rc3-megaraid-gcc34.patch
- add Patch2002: scx200-undefine.patch
- cancel use gcc3.2, now use gcc3.4

* Sun Oct 10 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-0.3.3m)
- cancel Patch10000 and Patch10001
- add and comment out 'delete inline sed lines' for qla2xxx and megaraid
- use gcc3.2
- update usagi patch 2.6.9-rc3-20041009
- add Source3090 for swsusp2
- add Patch90 for swsusp2
- update Patch530: linux-2.6.9-rc3-dbus.patch for adapt swsusp2 patch
- update config-*
- update Makefile.configdefs

* Sat Oct 02 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-0.3.2m)
- add Patch10000: drivers-scsi-qla2xxx-gcc34.patch
- add Patch10001: drivers-scsi-megaraid-gcc34.patch

* Fri Oct  1 2004 Tsutomu Yasuda <tom@tom.homelinux.org>
- (2.6.9-0.3.1m)
  update to 2.6.9-rc3
  removed mm patch, reiser4 unsupported

* Fri Sep 17 2004 Tsutomu Yasuda <tom@tom.homelinux.org>
- (2.6.8-15m)
  applied 2.6.8.1-mm4 patch(included reiser4 support).

* Thu Sep 16 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-14m)
- update spec to assign proper names for smp files [Momonga-devel.ja:02768]

* Sun Sep 12 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-13m)
- update usagi daily-snap date to 20040824 from 20040817
- add usagi_ipv6 as option for specopt and set 1 as default
- update ALSA driver to  version 1.0.7rc1
- add Patch1140: linux-2.6.8.1-usb2-storage.patch (reported by ryu)
  from http://www.mail-archive.com/linux-usb-devel@lists.sourceforge.net/msg27047.html

* Sun Sep 12 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-12m)
- add CPU specific kernel building options for Pentium4, Coppermine, AMD K7 and K8 CPUs.

* Sun Sep  5 2004 Shotaro Kamio <skamio@momonga-linux.org>
- (2.6.8-11m)
- add arch/x86_64/ to kernel-source (i586)
- add include/{media,mtd,rxrpc} to kernel-headers

* Fri Sep  3 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-10m)
- add Patch560: linux-2.6.8.1-crc-ccitt.patch

* Thu Sep  2 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-9m)
- change in config-generic
  CONFIG_APM=m                       [Momonga-devel.ja:02741] 
  CONFIG_APM_CPU_IDLE is not set     [Momonga-devel.ja:02741]
  CONFIG_APM_RTC_IS_GMT is not set   [Momonga-devel.ja:02741] 
  CONFIG_BLK_DEV_OFFBOARD=y          [Momonga-devel.ja:02741] 
  CONFIG_PPP_BSDCOMP=m

* Wed Sep  1 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-8m)
- change in config-generic
   CONFIG_USB_KBD=m
   CONFIG_USB_MOUSE=m
   CONFIG_REISERFS_CHECK is not set  [Momonga-devel.ja:02738] 

* Fri Aug 26 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-7m)
- change in config-generic (the following were not set)
    CONFIG_LEGACY_PTYS=y  [Momonga-users.ja:00139] 
    CONFIG_SCSI_DPT_I2O=m [Momonga-devel.ja:02732]

* Thu Aug 26 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-6m)
- add Patch1030: linux-2.6.8.1-ext3-reservations.patch
- add Patch1031: linux-2.6.8-ext3-reservations-update.patch
- add Patch1130: linux-2.6.7-i8x0-drm.patch
- remove /usr/src/linux-*/config-*
- disable kdb if specified in specopt

* Wed Aug 25 2004 Kazuhiko <kazuhiko@fdiary.net>
- (2.6.8-5m)
- revice config files

* Mon Aug 23 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-4m)
- merge some contents from kernel-2.6.8-i686.config by Fedora Core 
  to config-generic and config-x86-generic

* Sat Aug 21 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-3m)
- update alsa-driver to 1.0.6a
- added a forgotten link for asm-generic

* Tue Aug 17 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-2m)
- source version update to 2.6.8.1
- update alsa-driver to 1.0.6
- add Patch550: kernel2.6.8.1-kcalloc.patch

* Mon Aug  9 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.7-2m)
- update to alsa-1.0.6rc2
- update to hostap-driver-0.2.4 
- add libata driver
- update ieee1394 to 1233

* Sun Jun 20 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.7-1m)
- update to version 2.6.7
- update ieee1394 to 1228
- update to linux26-2.6.7-usagi-20040620
- edit Patch530 linux-2.6.7-dbus.patch from linux-2.6.5-dbus.patch
- remove Patch10000:  linux-2.6.6-compile.patch
- remove Patch10200:  linux-2.6.6-alsa-au88.patch
- clean up files no longer required to build

* Sun Jun 13 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.6-6m)
- edit Patch10000 linux-2.6.6-compile.patch from linux-2.6.1rc2-compile.patch
  not to remove EXPORT_SYMBOL(sys_close) from fs/open.c 

* Tue Jun  8 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.6-5m)
- update ALSA Driver 1.0.5a
- update hostap driver 0.2.2 
- add Patch10200 linux-2.6.6-alsa-au88.patch

* Mon Jun  7 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.6-4m)
- update to linux26-2.6.6-usagi-20040524
- update ieee1394 to 1222
- remove kernel26-CLEAR_BITMAP.patch

* Sun May 30 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.6-3m)
- add kernel26-CLEAR_BITMAP.patch

* Wed May 19 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.6-2m)
- update kdb files for kernel 2.6.6

* Tue May 18 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.6-1m)
- version update to 2.6.6
- removed linux-2.6.5-usagi-fix.patch
- edited linux-2.6.6-online-resize.patch from linux-2.6.0-online-resize.patch

* Mon Apr 26 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.5-3m)
- changed to use modinfo.old to correct behavior with kernel 2.6.x

* Wed Apr 21 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.5-2m)
- add symlinks to header files

* Wed Apr 21 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.5-1m)
- update to 2.6.5

* Sun Apr  4 2004 Toru Hoshina <t@momonga-linux.org>
- (2.6.3-6m)
- kernel-drm shoule be provides so that we keep interoperability with FC.
- CONFIG_DVB_SP887X and CONFIG_SND_USB_AUDIO is not set due to avoid
  undefined symbol warning.

* Wed Mar 24 2004 Toru Hoshina <t@momonga-linux.org>
- (2.6.3-5m)
- revised spec for rpm 4.2
- set _unpackaged_files_terminate_build as 0, avoid remove each messy stuff.

* Thu Mar 23 2004 Toru Hoshina <t@momonga-linux.org>
- (2.6.3-4m)
- AKK stands for Anti-Kossori-Kossori.

* Sat Mar  5 2004 Toru Hoshina <t@momonga-linux.org>
- (2.6.3-4m)
- acpi patch is updated kossorily.

* Mon Mar  1 2004 Toru Hoshina <t@momonga-linux.org>
- (2.6.3-3m)
- acpi patch is updated to 20040220.

* Mon Feb 23 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.3-2m)
- revise config-*
- import KDB patch( to enable kdb, "echo '1' > /proc/sys/kernel/kdb")

* Thu Feb 19 2004 Kazuhiko <kazuhiko@fdiary.net>
- (2.6.3-1m)
- import hostap-driver-0.2.0
- update ALSA to 1.0.2c
- revise dbus patch for 2.6.3

* Tue Feb 17 2004 Kazuhiko <kazuhiko@fdiary.net>
- (2.6.2-2m)
- update ALSA to 1.0.2a

* Tue Feb 17 2004 Toru Hoshina <t@momonga-linux.org>
- (2.6.1-1m)
- up to 2.6.2.
- usagi patch was changed to 2004-02-10.
- acpi patch also up to 20040116.

* Thu Jan 15 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.1-1m)
- update to 2.6.1
- update usagi to 2.6.1-20040115

* Wed Jan  7 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.1-0.rc2.1m)
- update to 2.6.1rc2
  this release includes security fix
- update usagi to 20040106

* Sat Dec 20 2003 Kenta MURATA <muraken2@nifty.com>
- (2.6.0-0.3m)
- replace boot logo to momonga.
- append verbose_make option, default is 0.

* Thu Dec 18 2003 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.0-0.2m)
- update acpipatch to 20031203-2.6.0
- fix cp Source10 to Source1

* Thu Dec 18 2003 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.0-0.1m)
- update to 2.6.0

* Tue Dec 16 2003 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.0-0.test11.4m)
- update acpi to 20031203
- update cpufreq to 20031215
- kernel26-source: fix wrong dependency on kernel-headers
- fix typo in cpufreq (linux-2.6.0-fix-cpufreq-typo.patch)

* Mon Dec 15 2003 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.0-0.test11.3m)
- add usagi patch
- remove bk patch

* Mon Dec 15 2003 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.0-0.test11.2m)
- add Linus's bk patch
- restrict version of module-init-tools
- add kernel-headers sub package

* Sun Dec 14 2003 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.0-0.test11.1m)
- write spec
   based on momonga's kernel-2.4.23-4m and fedora's kernel-2.6.0-0.test11.1.13


## TODO
# unicon??
# bttv, saa7134
# madwifi
# delete alpha and ppc from basearch
